/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvControlRandom.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvControlPack.h"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvSignalTabwrite.h"
#include "HvControlIf.h"
#include "HvControlDelay.h"
#include "HvSignalRPole.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvSignalPhasor.h"
#include "HvControlTabhead.h"
#include "HvMath.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_ecGbh7Pi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6udZ4HDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_oOxRVP8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Yi7gzrqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DA52khk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T19lDVAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_B6Onpznb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2avIbLMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bvxoc1AY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kcXx7fLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2uSqzw9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3Xmaj6wZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Hcpx75Mj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IXEwxUNN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_C5ROpFni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LRRkcF7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vjjgIKQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9cv4WB9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kTelGLMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iCzGiwdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zclCYb5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PrtEgQqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YJQH37gs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XZaPqEFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1Pls3hDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jpA9g1IE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8uEiaG0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LyrXfIYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7QC8tkS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2UoO3jlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZW2Y9i2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vW9nhsrM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DDbanNjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HlollCVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TsNN4y51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjAqbHEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GoaypJDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0RgdKmn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s5ycDWci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_INntfOWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ija23afH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jzfqo560_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8rIUb9Xs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3cwfJTZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wT6iHAek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_w2PNROKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UERDvgeh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_hjBcaDjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n99lwb6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HG9N1xLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oFtSjkRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qiGv1hop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KomC7zOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p5tx50YU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JqNt5NSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xhgCbjv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TcqC5IwL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B5qeGLW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2NTHRzYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nae4pOpS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZ3cv6jT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7xDOMNDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jFK3ytzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QO7lhFWO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_JEk4lt0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sAPfi4kI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_WZc0GDv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_2Q5G3UDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IoHipF4B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MAIZDTxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HMDl9jGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KFoQ1NoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_L53M5NsU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gTpuD0JE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2OhOwlQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OyjpFe3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eyAEOFEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DAyoHXKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_nQeYA8Dc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HHwDKevx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Cqmn6fLz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MWiNZmoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_exXkygV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1Ozma2OT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_BoWRiEAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10ZB6evT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6pPYGZUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VgPQ5zfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CkgSvUZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rKIpo1F6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nzkzUSXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CA5iR72e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qdvI7DSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i1cfppbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3TsVOKT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2NqXt2OV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yTLv7Qvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_6YtNdUPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SfGZkofv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YElW5Hov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bSLZvrQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EHXWv40U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_u9wwaf1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_IYp1yUn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B65xtonF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fIIZCUAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g6qIFpQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_V8XHgW9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P5mQulXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zi70Ub1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WbxrnGdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fFEte2XA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8dz3EKQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MCtrhHaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pRr67sAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jU42kNo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_0ZlMKHuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pE9bKwAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DnpgF8Jw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VG98i2zS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TFyItTPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_y57S2Ylp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_BKw3EDjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jFznnvz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4m0FfQA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BtFOau7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y9ZLvU82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qFX3USej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8zxP49Db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NJhpiO0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EHFb1bL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l83rFEmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JuVoeDX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zZwTfc55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vx9ESBAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_jXiMF1Vt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1boz8Av8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_abDTfFJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v7FY8Fh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AHVsc7xf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ykQ0qV9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5QalpX1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iopSyaSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRVpKlBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sZ9CiWnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_B6ALHtDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oMbboGB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mTdJKMo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5iOHH4as_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EulVszee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XC8Vuge8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JN4tU9jC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kgRDKURo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iNLAPskN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0zhCfikK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0DSRuIy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2NVEf02W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NRvpLjp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HgfhXxd7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_CEuzWDni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_HpTetOee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tEZHLlUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UChuBo4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iUtohmzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A2O2gkBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HGOv01VS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_exT04jLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yMqtiEPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RkhWFfyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Nt0a3iZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uTd9nqRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3fpLQm2L_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_kTYieLQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0a2W8LKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iFNddr8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_haD0AvCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wSA3kE5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aY3kDI7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CbYrM3Yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fNdOFVSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FjdaW0Lk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TmUfSLJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MWYzCfCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hSDA3zhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XBKM8o0G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_P15mTIhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_whBMTTMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kIZKeRVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j9gc1aSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9gkjqwJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vWNmE7dr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MZBzW8Yu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WxbanugR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XWadHjB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dWevqiBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KCpTgXxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ybcoGYS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A8mxhc2G_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WKC2QRi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_pHy8DdDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JE4MDzLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wgsePqoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o8s379sM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OkvdqjrC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WsJWqRJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KLD2Zwnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_UNmOIkwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_jVYDFhRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rVNWkkdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kV2LWPVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IWTnBYd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qGparK4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9KEZyLFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_htqUAocQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YZG4URqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x5vkbLwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_blX2poEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VeIt2krC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgURDG8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3cgJmL8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iiayiZRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_b1OFOz1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HW7U9ZHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x93Q50IA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dGe36C9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dhJPpSEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_73LTISQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_orYXb1Bz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HBQ91Vz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uThYhCDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sWw1ciDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XyeU0LmV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VZOMB4EB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_qSFowkX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ukXjmt6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rsnqE6Iq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oQjg0FHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oLXNY8ZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Am0GggxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V7UChskA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_OzI7Xhu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCwKpdd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SlaOEuvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PouJAbr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8rL6pUAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_b5Z4L2zY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_UMrkrym0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FZBt8MbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jQgJgk8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DqLoHcLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SO0HS9xZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fVzX12xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HexcTF5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XOVp3GPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61iGpHBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PxqXByTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OWGQf8AJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VtJXpr2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eu7QW3fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_usTKcGH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tQKnqwVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Rb0aoBWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_loxPmR17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VzRbnAuu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8o1NwYpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_vltz66uy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PJLogsLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Et66QgfC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_StKKq2uU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s5vDqT8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YvzY8odj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FVES5Tv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_3fIiqIPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vURJfGht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y6CY488H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Pn9HIzjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oGq9isCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oadob5St_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_H5SZR1fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7HfvDIBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gSGJyjXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kcKPnwBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dmAKpDqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mecP0stu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tjzd1xQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GpugSUnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8QrPw7Bx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zTSLeMKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eNEB1GI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_92RpitzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zv2pQces_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G0dYoS4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SyZU3J6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Sqd81UUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_K7WU35lE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s8Qs9QY6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9LsSzc1d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_KZZX2aen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KYumHYGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JFRjwU2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gR3Bavre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lXqhUDK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCyXYmxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HOu6DNMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_pubX3OCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kxIHDoQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iQuJJXJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u17uO8S7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xybTaEZ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sgbijApR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_x30HpyjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pSq5tvfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1DpYAJzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R96IYYBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Lj22cfvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aXhxwIB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vHzL65aM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tEGHp8nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NWtpJkUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YcaApIIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JeEbxhxW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cTDHmy6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uunBNuty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g2LO3srC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FLXVzOQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_61s11ttn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Fy3jDNph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_C0aJuUay_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wpTDv6MH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_CqZa4dOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_libVE4XP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cetwItHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rbCEysyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Phq50KOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E4Nipt8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c7KxpNJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_IPF5ofO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IomwOMaU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_k83xGnfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kbwKxudN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PTC8FvhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qxKqVmA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_mXX5ho42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tjvTFoI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EDBvZr25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vTpr4f1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EF9vkz7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j35PcXok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sLTtz7CJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_osYIFwwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzwmj45j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o2Ilqz8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XqJBzcqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PRSeWIjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wqmPiQGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B1z5Q4VV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_k7EvwcWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7AWI6Z7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fQ1jdQnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aDBwF4Qu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_tH5mBrYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Hl9ouB9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TyCOZFyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zxr4N8mU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_31GpjrGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PTQvloTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5zAye0ux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0fxaAXAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_uCDU8DiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cWLvY9Ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z6abnGJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tYwdfKC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WQ6ckqwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6ortthpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Tr02v7aG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y7OulpxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8cytcgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DU24dBu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rMCtM5PA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vI4nbPHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LYGX6EIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hy38LkkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9cd5tGvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R4iRCX14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQt90RFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6PRLHJST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iqy1iyY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rUYKdLsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7g33YLxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sjDaXDm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_c7xMRkPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yc0YHHki_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_NNHdZoeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_mVQXDqrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F4IJPfXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fsncIhj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XaaOgxhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WqrHU9Wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tuMmeV1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LAw1691c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5OCkNgOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xZYbFLKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xGQdCzvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BHbgXlxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lBcoTXiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h6mOJgro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_dMJfdbuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LdhRhKO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cE16Z1Cz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GvVGMMn9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ysM9hmwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kc4DBaLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XTTy9Yma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zAhpqgny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h9jelHh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MyeZUltC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3rC2IuUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZisK3F68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hBHd8bhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZfSPXr3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_475jASrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_xQKMj2Cy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ha3HZMDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qduUvhHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4rZXE07f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VqHIW0m1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_atArv2Az_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yg7MJJxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qOssjVpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BlbonMfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bsyIoXtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_py3ZK261_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wiSUTIWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sEWAln1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7iAViFwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P9aMABV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x95E4aKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JKUwPAo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IrttXLGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EdPlh42F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p0V8mYsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HjyzjNf6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g6zH3NqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7xdkIxee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CrLw5W7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JWlGpp1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dmmi4cPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tBJg2rAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Cht9Omr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHSig2Q1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6sSlmcMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ufkkuzCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hWNvx1i4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yS0Xohiz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zayFWd6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1BRTmj3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cIdDZ3mI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2HNXqKmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yAnfxD7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ueEBV7Gr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mJrCuS4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9nCDOnOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tp6TIjc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2HYqYUV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8Jc5ghAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jRGuBfTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5JlJ5GnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HMvwWhqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xT8iD6yK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SShF5cLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_W7auimcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PFYEcAlV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mOiWrE50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_elCf0inE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_dgTlsISu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_CGqfSKGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wzdBq8vo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_udL8UKIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JCORFIIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rDPY2NsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8GwLqCqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MRvyDH6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_l59eVvd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Y3QB9JX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kD3wOJx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hHH8mEMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WBYcI5GO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nEotHceT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_XXtHz2aJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tngAvvZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yPEwTWXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwgYw1Am_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nC82d24v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_72LmSIOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XT1FwWDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OK5WTQkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cLYrA2zp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ksWFUmTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10LKd2FU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oUqEXHhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zCBZ1YsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oA6FEcXo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jcTMzaqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BVCti94y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1XXzireO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_oHbWtBAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j2HEoNIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tbKx8pA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KoPqWL1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4DQkKYwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r0lx1Kec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_58eu0Rt7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qJaCkDz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qrv9niaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iaCECi2l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Di8H8Ty7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eYh8fALV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_v35VamBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_a2oqWU0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NVGbXpBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AMA2fL8t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_iwTckHZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_IBlNnetp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TJQq2K5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_D3RtrD0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z5EWNhWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zPixovGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dMJkmgrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FtwUpKJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WizEAHd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0F47aLpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rnAvuRed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DtELNm5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4973xQPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GUN4WcUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mJn4VgTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L3c3KXCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xDIf1Jzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fxCzYGyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dj984SFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SxbpIqlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8cHXomhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2pZWL2hY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7oI9T88q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lh4WxEZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ymHTXyPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ERibUBT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AyNSscE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GtHxzk9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U1qwUw5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QOFuJAZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sBZybc12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CNZxVeAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2A8thIbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8dPAvibl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IywhcCvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_meImHsqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BgR05A1x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qL0ZZOBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OPeI5mh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtSI9g9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HfSV1rv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJKuuL5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MEzmc73m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HAC5fZ19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WeL1XDLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U5G0Epuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hv2Dnt08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jArgfx3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u4ZBsrIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X4PDonJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d3z40l1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fpB6eIky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kw81lHop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XTffoJ45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dRWfjwQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UgediTC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2QI4eThF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U1x8Eucj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFJsRKZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ir3cJYZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eSRPWwuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_emJwa5yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ANXHegV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HNLJRgiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QVkt4wEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZXpglU67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ei0OBn51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pIWxbU7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aE1Sk30e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DZbXOBVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SXlY6XOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7wnATPM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7yKVXtb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FtBOPv9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0ITo3QOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pz0No5CA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_67PYWRIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JTWmXBUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lOYjLDod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j6rBFqld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OKGH1aHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Kn6MXJ8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ArJ44XwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eT2cHFC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_0VjlSm5H;
  SignalLine sLine_oqGF3J4a;
  SignalLine sLine_s9rLL2Zw;
  SignalTabhead sTabhead_tfA052OY;
  SignalTabread sTabread_CGAJlvDG;
  SignalTabread sTabread_EYbzL6TP;
  SignalTabhead sTabhead_uvN1tyDm;
  SignalTabread sTabread_0g303sTK;
  SignalTabread sTabread_8IvGfGMS;
  SignalTabwrite sTabwrite_4fx4BH2w;
  SignalRPole sRPole_pxnBlMo1;
  SignalDel1 sDel1_bBi8lbUv;
  SignalTabread sTabread_XXtHz2aJ;
  SignalTabwrite sTabwrite_pQOGuKzg;
  SignalTabread sTabread_BoWRiEAT;
  SignalRPole sRPole_c0ZISSra;
  SignalLine sLine_NA1DmgYx;
  SignalLine sLine_dTjgUxY3;
  SignalTabread sTabread_UMrkrym0;
  SignalTabread sTabread_H5SZR1fn;
  SignalTabread sTabread_x30HpyjE;
  SignalTabread sTabread_mXX5ho42;
  SignalTabread sTabread_dMJfdbuF;
  SignalTabread sTabread_Tr02v7aG;
  SignalTabwrite sTabwrite_K0uXIN5h;
  SignalTabwrite sTabwrite_GVaU32Uj;
  SignalTabwrite sTabwrite_DyikTmQA;
  SignalTabwrite sTabwrite_XgEPBFuq;
  SignalTabwrite sTabwrite_XjNCXCCx;
  SignalTabwrite sTabwrite_VtQhKxcn;
  SignalTabread sTabread_IYp1yUn7;
  SignalRPole sRPole_gqX9U0Gp;
  SignalTabread sTabread_BKw3EDjM;
  SignalRPole sRPole_1Mw648mB;
  SignalTabread sTabread_5QalpX1l;
  SignalRPole sRPole_nyUJhD1X;
  SignalTabwrite sTabwrite_WwHAjcJL;
  SignalTabwrite sTabwrite_PC3Un7ur;
  SignalTabwrite sTabwrite_pAP82yt1;
  SignalTabwrite sTabwrite_Y6JA3G1e;
  SignalLine sLine_1eMOLNSD;
  ControlVar cVar_ecGbh7Pi;
  ControlVar cVar_6udZ4HDi;
  ControlPack cPack_oOxRVP8O;
  ControlBinop cBinop_DA52khk1;
  ControlVar cVar_T19lDVAO;
  ControlPack cPack_B6Onpznb;
  ControlVar cVar_2avIbLMp;
  ControlVar cVar_bvxoc1AY;
  ControlDelay cDelay_3Xmaj6wZ;
  ControlDelay cDelay_Hcpx75Mj;
  ControlBinop cBinop_C5ROpFni;
  HvTable hTable_LRRkcF7J;
  ControlBinop cBinop_9cv4WB9X;
  ControlVar cVar_1Pls3hDc;
  ControlBinop cBinop_8uEiaG0i;
  ControlBinop cBinop_7QC8tkS0;
  SignalVarf sVarf_uXOp2dFT;
  SignalVarf sVarf_0WZR9ohu;
  SignalVarf sVarf_go125gOo;
  ControlVar cVar_vW9nhsrM;
  ControlBinop cBinop_HlollCVG;
  ControlBinop cBinop_CjAqbHEC;
  SignalVarf sVarf_Zwp2llak;
  SignalVarf sVarf_Bdp4hO8E;
  SignalVarf sVarf_6wjKPV7N;
  ControlBinop cBinop_GoaypJDz;
  ControlBinop cBinop_0RgdKmn6;
  ControlBinop cBinop_Ija23afH;
  ControlBinop cBinop_jzfqo560;
  ControlBinop cBinop_8rIUb9Xs;
  ControlBinop cBinop_3cwfJTZF;
  ControlBinop cBinop_wT6iHAek;
  ControlBinop cBinop_oFtSjkRs;
  ControlBinop cBinop_qiGv1hop;
  SignalVarf sVarf_QkBR6cn3;
  ControlVar cVar_KomC7zOL;
  ControlBinop cBinop_xhgCbjv1;
  ControlBinop cBinop_TcqC5IwL;
  ControlBinop cBinop_2NTHRzYY;
  ControlBinop cBinop_Nae4pOpS;
  ControlBinop cBinop_HZ3cv6jT;
  ControlBinop cBinop_7xDOMNDy;
  ControlBinop cBinop_jFK3ytzX;
  SignalVarf sVarf_APXmZaAy;
  ControlBinop cBinop_JEk4lt0i;
  ControlRandom cRandom_WZc0GDv2;
  ControlSlice cSlice_2Q5G3UDe;
  ControlDelay cDelay_MAIZDTxL;
  ControlVar cVar_gTpuD0JE;
  ControlBinop cBinop_OyjpFe3D;
  ControlBinop cBinop_eyAEOFEb;
  ControlBinop cBinop_DAyoHXKj;
  ControlTabhead cTabhead_nQeYA8Dc;
  ControlVar cVar_MWiNZmoj;
  ControlDelay cDelay_exXkygV6;
  ControlDelay cDelay_1Ozma2OT;
  ControlBinop cBinop_10ZB6evT;
  ControlBinop cBinop_6pPYGZUf;
  ControlBinop cBinop_VgPQ5zfj;
  ControlBinop cBinop_qdvI7DSp;
  ControlBinop cBinop_3TsVOKT4;
  ControlBinop cBinop_2NqXt2OV;
  ControlTabhead cTabhead_6YtNdUPX;
  ControlVar cVar_bSLZvrQH;
  ControlDelay cDelay_EHXWv40U;
  ControlDelay cDelay_u9wwaf1U;
  ControlBinop cBinop_B65xtonF;
  ControlBinop cBinop_fIIZCUAB;
  ControlBinop cBinop_g6qIFpQq;
  ControlBinop cBinop_fFEte2XA;
  ControlBinop cBinop_MCtrhHaH;
  ControlBinop cBinop_pRr67sAd;
  ControlTabhead cTabhead_0ZlMKHuY;
  ControlVar cVar_VG98i2zS;
  ControlDelay cDelay_TFyItTPg;
  ControlDelay cDelay_y57S2Ylp;
  ControlBinop cBinop_jFznnvz5;
  ControlBinop cBinop_4m0FfQA6;
  ControlBinop cBinop_BtFOau7t;
  ControlBinop cBinop_EHFb1bL5;
  ControlBinop cBinop_JuVoeDX7;
  ControlBinop cBinop_zZwTfc55;
  ControlTabhead cTabhead_jXiMF1Vt;
  ControlVar cVar_v7FY8Fh3;
  ControlDelay cDelay_AHVsc7xf;
  ControlDelay cDelay_ykQ0qV9C;
  ControlBinop cBinop_iopSyaSk;
  ControlBinop cBinop_vRVpKlBc;
  ControlBinop cBinop_sZ9CiWnV;
  ControlBinop cBinop_EulVszee;
  ControlBinop cBinop_JN4tU9jC;
  ControlBinop cBinop_kgRDKURo;
  ControlDelay cDelay_2NVEf02W;
  ControlDelay cDelay_NRvpLjp3;
  ControlBinop cBinop_CEuzWDni;
  HvTable hTable_HpTetOee;
  ControlBinop cBinop_UChuBo4r;
  ControlDelay cDelay_Nt0a3iZb;
  ControlDelay cDelay_uTd9nqRw;
  ControlBinop cBinop_kTYieLQy;
  HvTable hTable_0a2W8LKT;
  ControlBinop cBinop_haD0AvCy;
  ControlDelay cDelay_MWYzCfCk;
  ControlDelay cDelay_hSDA3zhN;
  ControlBinop cBinop_P15mTIhh;
  HvTable hTable_whBMTTMF;
  ControlBinop cBinop_j9gc1aSg;
  ControlDelay cDelay_KCpTgXxP;
  ControlDelay cDelay_ybcoGYS6;
  ControlBinop cBinop_WKC2QRi2;
  HvTable hTable_pHy8DdDl;
  ControlBinop cBinop_wgsePqoG;
  ControlPack cPack_UNmOIkwS;
  ControlPack cPack_jVYDFhRL;
  ControlBinop cBinop_rVNWkkdQ;
  ControlBinop cBinop_kV2LWPVx;
  ControlVar cVar_IWTnBYd3;
  ControlBinop cBinop_htqUAocQ;
  ControlBinop cBinop_YZG4URqZ;
  SignalVarf sVarf_oO75cqZB;
  ControlBinop cBinop_blX2poEA;
  ControlBinop cBinop_VeIt2krC;
  ControlBinop cBinop_rgURDG8j;
  SignalVarf sVarf_5vDhtPJB;
  ControlVar cVar_3cgJmL8v;
  ControlVar cVar_iiayiZRw;
  ControlVar cVar_b1OFOz1j;
  ControlVar cVar_HW7U9ZHZ;
  ControlIf cIf_x93Q50IA;
  ControlBinop cBinop_dGe36C9U;
  ControlBinop cBinop_dhJPpSEo;
  ControlBinop cBinop_73LTISQv;
  ControlDelay cDelay_uThYhCDM;
  ControlDelay cDelay_sWw1ciDS;
  ControlBinop cBinop_VZOMB4EB;
  HvTable hTable_qSFowkX0;
  ControlBinop cBinop_rsnqE6Iq;
  ControlTabhead cTabhead_OzI7Xhu9;
  ControlVar cVar_PouJAbr4;
  ControlDelay cDelay_8rL6pUAe;
  ControlDelay cDelay_b5Z4L2zY;
  ControlBinop cBinop_FZBt8MbL;
  ControlBinop cBinop_jQgJgk8X;
  ControlBinop cBinop_DqLoHcLm;
  ControlBinop cBinop_61iGpHBC;
  ControlBinop cBinop_OWGQf8AJ;
  ControlBinop cBinop_VtJXpr2Y;
  ControlDelay cDelay_Rb0aoBWx;
  ControlDelay cDelay_loxPmR17;
  ControlBinop cBinop_8o1NwYpf;
  HvTable hTable_vltz66uy;
  ControlBinop cBinop_Et66QgfC;
  ControlTabhead cTabhead_3fIiqIPM;
  ControlVar cVar_Pn9HIzjw;
  ControlDelay cDelay_oGq9isCK;
  ControlDelay cDelay_oadob5St;
  ControlBinop cBinop_7HfvDIBO;
  ControlBinop cBinop_gSGJyjXq;
  ControlBinop cBinop_kcKPnwBU;
  ControlBinop cBinop_8QrPw7Bx;
  ControlBinop cBinop_9eNEB1GI;
  ControlBinop cBinop_92RpitzW;
  ControlDelay cDelay_Sqd81UUH;
  ControlDelay cDelay_K7WU35lE;
  ControlBinop cBinop_9LsSzc1d;
  HvTable hTable_KZZX2aen;
  ControlBinop cBinop_JFRjwU2U;
  ControlTabhead cTabhead_pubX3OCm;
  ControlVar cVar_u17uO8S7;
  ControlDelay cDelay_xybTaEZ2;
  ControlDelay cDelay_sgbijApR;
  ControlBinop cBinop_pSq5tvfx;
  ControlBinop cBinop_1DpYAJzU;
  ControlBinop cBinop_R96IYYBo;
  ControlBinop cBinop_NWtpJkUM;
  ControlBinop cBinop_JeEbxhxW;
  ControlBinop cBinop_cTDHmy6Q;
  ControlDelay cDelay_61s11ttn;
  ControlDelay cDelay_Fy3jDNph;
  ControlBinop cBinop_wpTDv6MH;
  HvTable hTable_CqZa4dOv;
  ControlBinop cBinop_cetwItHr;
  ControlTabhead cTabhead_IPF5ofO5;
  ControlVar cVar_kbwKxudN;
  ControlDelay cDelay_PTC8FvhY;
  ControlDelay cDelay_qxKqVmA3;
  ControlBinop cBinop_tjvTFoI5;
  ControlBinop cBinop_EDBvZr25;
  ControlBinop cBinop_vTpr4f1Q;
  ControlBinop cBinop_nzwmj45j;
  ControlBinop cBinop_XqJBzcqO;
  ControlBinop cBinop_PRSeWIjR;
  ControlDelay cDelay_7AWI6Z7Z;
  ControlDelay cDelay_fQ1jdQnd;
  ControlBinop cBinop_tH5mBrYn;
  HvTable hTable_Hl9ouB9e;
  ControlBinop cBinop_zxr4N8mU;
  ControlTabhead cTabhead_uCDU8DiK;
  ControlVar cVar_tYwdfKC4;
  ControlDelay cDelay_WQ6ckqwV;
  ControlDelay cDelay_6ortthpd;
  ControlBinop cBinop_Y7OulpxK;
  ControlBinop cBinop_L8cytcgI;
  ControlBinop cBinop_DU24dBu0;
  ControlBinop cBinop_9cd5tGvX;
  ControlBinop cBinop_fQt90RFM;
  ControlBinop cBinop_6PRLHJST;
  ControlDelay cDelay_sjDaXDm8;
  ControlDelay cDelay_c7xMRkPh;
  ControlBinop cBinop_NNHdZoeJ;
  HvTable hTable_mVQXDqrJ;
  ControlBinop cBinop_fsncIhj6;
  ControlTabhead cTabhead_5OCkNgOM;
  ControlVar cVar_BHbgXlxj;
  ControlDelay cDelay_lBcoTXiy;
  ControlDelay cDelay_h6mOJgro;
  ControlBinop cBinop_LdhRhKO0;
  ControlBinop cBinop_cE16Z1Cz;
  ControlBinop cBinop_GvVGMMn9;
  ControlBinop cBinop_h9jelHh7;
  ControlBinop cBinop_3rC2IuUa;
  ControlBinop cBinop_ZisK3F68;
  ControlVar cVar_ZfSPXr3T;
  ControlVar cVar_475jASrs;
  ControlPack cPack_xQKMj2Cy;
  ControlVar cVar_ha3HZMDR;
  ControlBinop cBinop_VqHIW0m1;
  ControlBinop cBinop_atArv2Az;
  SignalVarf sVarf_x6e8wN31;
  ControlBinop cBinop_qOssjVpt;
  ControlBinop cBinop_BlbonMfu;
  ControlBinop cBinop_bsyIoXtd;
  SignalVarf sVarf_Pf9CTUyK;
  ControlVar cVar_py3ZK261;
  ControlBinop cBinop_7iAViFwZ;
  ControlBinop cBinop_P9aMABV9;
  SignalVarf sVarf_GZjrIoYq;
  ControlBinop cBinop_JKUwPAo2;
  ControlBinop cBinop_IrttXLGY;
  ControlBinop cBinop_EdPlh42F;
  SignalVarf sVarf_Sc8QRQ1L;
  ControlVar cVar_p0V8mYsc;
  ControlBinop cBinop_7xdkIxee;
  ControlBinop cBinop_CrLw5W7u;
  SignalVarf sVarf_9x8oP7Qq;
  ControlBinop cBinop_Dmmi4cPS;
  ControlBinop cBinop_tBJg2rAT;
  ControlBinop cBinop_6Cht9Omr;
  SignalVarf sVarf_lVw1x0QF;
  ControlBinop cBinop_PHSig2Q1;
  ControlBinop cBinop_ufkkuzCq;
  ControlBinop cBinop_hWNvx1i4;
  ControlDelay cDelay_zayFWd6Q;
  ControlVar cVar_yAnfxD7C;
  ControlBinop cBinop_mJrCuS4O;
  ControlBinop cBinop_9nCDOnOI;
  ControlBinop cBinop_tp6TIjc6;
  ControlVar cVar_2HYqYUV3;
  ControlVar cVar_8Jc5ghAm;
  ControlIf cIf_HMvwWhqw;
  ControlBinop cBinop_xT8iD6yK;
  ControlDelay cDelay_PFYEcAlV;
  ControlDelay cDelay_mOiWrE50;
  ControlBinop cBinop_dgTlsISu;
  HvTable hTable_CGqfSKGI;
  ControlBinop cBinop_udL8UKIF;
  ControlTabhead cTabhead_l59eVvd7;
  ControlVar cVar_hHH8mEMQ;
  ControlDelay cDelay_WBYcI5GO;
  ControlDelay cDelay_nEotHceT;
  ControlBinop cBinop_tngAvvZI;
  ControlBinop cBinop_yPEwTWXm;
  ControlBinop cBinop_SwgYw1Am;
  ControlBinop cBinop_cLYrA2zp;
  ControlBinop cBinop_10LKd2FU;
  ControlBinop cBinop_oUqEXHhX;
  ControlVar cVar_BVCti94y;
  ControlVar cVar_j2HEoNIl;
  ControlVar cVar_tbKx8pA1;
  ControlVar cVar_KoPqWL1n;
  ControlVar cVar_4DQkKYwK;
  ControlVar cVar_r0lx1Kec;
  ControlIf cIf_qrv9niaV;
  ControlBinop cBinop_iaCECi2l;
  ControlVar cVar_Di8H8Ty7;
  ControlIf cIf_a2oqWU0F;
  ControlBinop cBinop_NVGbXpBa;
  ControlSlice cSlice_iwTckHZX;
  ControlSlice cSlice_IBlNnetp;
  ControlVar cVar_TJQq2K5k;
  ControlIf cIf_D3RtrD0a;
  ControlBinop cBinop_dMJkmgrs;
  ControlIf cIf_0F47aLpB;
  ControlIf cIf_rnAvuRed;
  ControlIf cIf_DtELNm5Z;
  ControlIf cIf_4973xQPn;
  ControlIf cIf_GUN4WcUy;
  SignalVarf sVarf_ev7W7Fie;
  ControlBinop cBinop_dj984SFC;
  ControlBinop cBinop_SxbpIqlF;
  ControlBinop cBinop_2pZWL2hY;
  ControlBinop cBinop_7oI9T88q;
  SignalVarf sVarf_7yFkJW6y;
  ControlBinop cBinop_ymHTXyPK;
  ControlBinop cBinop_ERibUBT7;
  SignalVarf sVarf_hau0OBsI;
  SignalVarf sVarf_TQKWY23o;
  ControlBinop cBinop_sBZybc12;
  ControlBinop cBinop_CNZxVeAl;
  ControlBinop cBinop_2A8thIbY;
  ControlBinop cBinop_8dPAvibl;
  ControlBinop cBinop_meImHsqF;
  ControlBinop cBinop_BgR05A1x;
  ControlBinop cBinop_qL0ZZOBu;
  ControlBinop cBinop_OPeI5mh2;
  ControlBinop cBinop_HfSV1rv8;
  ControlBinop cBinop_lJKuuL5u;
  ControlBinop cBinop_MEzmc73m;
  ControlBinop cBinop_XTffoJ45;
  ControlBinop cBinop_dRWfjwQ0;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
