/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_0VjlSm5H, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_oqGF3J4a);
  numBytes += sLine_init(&sLine_s9rLL2Zw);
  numBytes += sTabhead_init(&sTabhead_tfA052OY, &hTable_LRRkcF7J);
  numBytes += sTabread_init(&sTabread_CGAJlvDG, &hTable_LRRkcF7J, false);
  numBytes += sTabread_init(&sTabread_EYbzL6TP, &hTable_LRRkcF7J, false);
  numBytes += sTabhead_init(&sTabhead_uvN1tyDm, &hTable_LRRkcF7J);
  numBytes += sTabread_init(&sTabread_0g303sTK, &hTable_LRRkcF7J, false);
  numBytes += sTabread_init(&sTabread_8IvGfGMS, &hTable_LRRkcF7J, false);
  numBytes += sTabwrite_init(&sTabwrite_4fx4BH2w, &hTable_LRRkcF7J);
  numBytes += sRPole_init(&sRPole_pxnBlMo1);
  numBytes += sDel1_init(&sDel1_bBi8lbUv);
  numBytes += sTabread_init(&sTabread_XXtHz2aJ, &hTable_CGqfSKGI, true);
  numBytes += sTabwrite_init(&sTabwrite_pQOGuKzg, &hTable_CGqfSKGI);
  numBytes += sTabread_init(&sTabread_BoWRiEAT, &hTable_HpTetOee, true);
  numBytes += sRPole_init(&sRPole_c0ZISSra);
  numBytes += sLine_init(&sLine_NA1DmgYx);
  numBytes += sLine_init(&sLine_dTjgUxY3);
  numBytes += sTabread_init(&sTabread_UMrkrym0, &hTable_qSFowkX0, true);
  numBytes += sTabread_init(&sTabread_H5SZR1fn, &hTable_vltz66uy, true);
  numBytes += sTabread_init(&sTabread_x30HpyjE, &hTable_KZZX2aen, true);
  numBytes += sTabread_init(&sTabread_mXX5ho42, &hTable_CqZa4dOv, true);
  numBytes += sTabread_init(&sTabread_dMJfdbuF, &hTable_mVQXDqrJ, true);
  numBytes += sTabread_init(&sTabread_Tr02v7aG, &hTable_Hl9ouB9e, true);
  numBytes += sTabwrite_init(&sTabwrite_K0uXIN5h, &hTable_qSFowkX0);
  numBytes += sTabwrite_init(&sTabwrite_GVaU32Uj, &hTable_vltz66uy);
  numBytes += sTabwrite_init(&sTabwrite_DyikTmQA, &hTable_KZZX2aen);
  numBytes += sTabwrite_init(&sTabwrite_XgEPBFuq, &hTable_CqZa4dOv);
  numBytes += sTabwrite_init(&sTabwrite_XjNCXCCx, &hTable_Hl9ouB9e);
  numBytes += sTabwrite_init(&sTabwrite_VtQhKxcn, &hTable_mVQXDqrJ);
  numBytes += sTabread_init(&sTabread_IYp1yUn7, &hTable_0a2W8LKT, true);
  numBytes += sRPole_init(&sRPole_gqX9U0Gp);
  numBytes += sTabread_init(&sTabread_BKw3EDjM, &hTable_whBMTTMF, true);
  numBytes += sRPole_init(&sRPole_1Mw648mB);
  numBytes += sTabread_init(&sTabread_5QalpX1l, &hTable_pHy8DdDl, true);
  numBytes += sRPole_init(&sRPole_nyUJhD1X);
  numBytes += sTabwrite_init(&sTabwrite_WwHAjcJL, &hTable_HpTetOee);
  numBytes += sTabwrite_init(&sTabwrite_PC3Un7ur, &hTable_0a2W8LKT);
  numBytes += sTabwrite_init(&sTabwrite_pAP82yt1, &hTable_whBMTTMF);
  numBytes += sTabwrite_init(&sTabwrite_Y6JA3G1e, &hTable_pHy8DdDl);
  numBytes += sLine_init(&sLine_1eMOLNSD);
  numBytes += cVar_init_f(&cVar_ecGbh7Pi, 0.0f);
  numBytes += cVar_init_f(&cVar_6udZ4HDi, 0.0f);
  numBytes += cPack_init(&cPack_oOxRVP8O, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_T19lDVAO, 0.0f);
  numBytes += cPack_init(&cPack_B6Onpznb, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_2avIbLMp, 0.0f);
  numBytes += cVar_init_f(&cVar_bvxoc1AY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3Xmaj6wZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Hcpx75Mj, 0.0f);
  numBytes += hTable_init(&hTable_LRRkcF7J, 256);
  numBytes += cVar_init_s(&cVar_1Pls3hDc, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_uXOp2dFT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0WZR9ohu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_go125gOo, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_vW9nhsrM, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_Zwp2llak, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bdp4hO8E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6wjKPV7N, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_GoaypJDz, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_QkBR6cn3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KomC7zOL, 0.0f);
  numBytes += cBinop_init(&cBinop_jFK3ytzX, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_APXmZaAy, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_WZc0GDv2, 123389211);
  numBytes += cSlice_init(&cSlice_2Q5G3UDe, 1, 1);
  numBytes += cDelay_init(this, &cDelay_MAIZDTxL, 0.0f);
  numBytes += cVar_init_f(&cVar_gTpuD0JE, 5.0f);
  numBytes += cBinop_init(&cBinop_DAyoHXKj, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_nQeYA8Dc, &hTable_HpTetOee);
  numBytes += cVar_init_s(&cVar_MWiNZmoj, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_exXkygV6, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_1Ozma2OT, 0.0f);
  numBytes += cBinop_init(&cBinop_10ZB6evT, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_VgPQ5zfj, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_qdvI7DSp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2NqXt2OV, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_6YtNdUPX, &hTable_0a2W8LKT);
  numBytes += cVar_init_s(&cVar_bSLZvrQH, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_EHXWv40U, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_u9wwaf1U, 0.0f);
  numBytes += cBinop_init(&cBinop_B65xtonF, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_g6qIFpQq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_fFEte2XA, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_pRr67sAd, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_0ZlMKHuY, &hTable_whBMTTMF);
  numBytes += cVar_init_s(&cVar_VG98i2zS, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_TFyItTPg, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_y57S2Ylp, 0.0f);
  numBytes += cBinop_init(&cBinop_jFznnvz5, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_BtFOau7t, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_EHFb1bL5, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_zZwTfc55, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_jXiMF1Vt, &hTable_pHy8DdDl);
  numBytes += cVar_init_s(&cVar_v7FY8Fh3, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_AHVsc7xf, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_ykQ0qV9C, 0.0f);
  numBytes += cBinop_init(&cBinop_iopSyaSk, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_sZ9CiWnV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_EulVszee, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kgRDKURo, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_2NVEf02W, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NRvpLjp3, 0.0f);
  numBytes += hTable_init(&hTable_HpTetOee, 256);
  numBytes += cDelay_init(this, &cDelay_Nt0a3iZb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uTd9nqRw, 0.0f);
  numBytes += hTable_init(&hTable_0a2W8LKT, 256);
  numBytes += cDelay_init(this, &cDelay_MWYzCfCk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hSDA3zhN, 0.0f);
  numBytes += hTable_init(&hTable_whBMTTMF, 256);
  numBytes += cDelay_init(this, &cDelay_KCpTgXxP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ybcoGYS6, 0.0f);
  numBytes += hTable_init(&hTable_pHy8DdDl, 256);
  numBytes += cPack_init(&cPack_UNmOIkwS, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_jVYDFhRL, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_IWTnBYd3, 22050.0f);
  numBytes += cBinop_init(&cBinop_htqUAocQ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_oO75cqZB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5vDhtPJB, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3cgJmL8v, 0.0f);
  numBytes += cVar_init_f(&cVar_iiayiZRw, 0.0f);
  numBytes += cVar_init_f(&cVar_b1OFOz1j, 0.0f);
  numBytes += cVar_init_f(&cVar_HW7U9ZHZ, 0.0f);
  numBytes += cIf_init(&cIf_x93Q50IA, false);
  numBytes += cDelay_init(this, &cDelay_uThYhCDM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sWw1ciDS, 0.0f);
  numBytes += hTable_init(&hTable_qSFowkX0, 256);
  numBytes += cTabhead_init(&cTabhead_OzI7Xhu9, &hTable_qSFowkX0);
  numBytes += cVar_init_s(&cVar_PouJAbr4, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_8rL6pUAe, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_b5Z4L2zY, 0.0f);
  numBytes += cBinop_init(&cBinop_FZBt8MbL, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_DqLoHcLm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_61iGpHBC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_VtJXpr2Y, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Rb0aoBWx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_loxPmR17, 0.0f);
  numBytes += hTable_init(&hTable_vltz66uy, 256);
  numBytes += cTabhead_init(&cTabhead_3fIiqIPM, &hTable_vltz66uy);
  numBytes += cVar_init_s(&cVar_Pn9HIzjw, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_oGq9isCK, 25.796f);
  numBytes += cDelay_init(this, &cDelay_oadob5St, 0.0f);
  numBytes += cBinop_init(&cBinop_7HfvDIBO, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_kcKPnwBU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8QrPw7Bx, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_92RpitzW, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Sqd81UUH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_K7WU35lE, 0.0f);
  numBytes += hTable_init(&hTable_KZZX2aen, 256);
  numBytes += cTabhead_init(&cTabhead_pubX3OCm, &hTable_KZZX2aen);
  numBytes += cVar_init_s(&cVar_u17uO8S7, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_xybTaEZ2, 19.392f);
  numBytes += cDelay_init(this, &cDelay_sgbijApR, 0.0f);
  numBytes += cBinop_init(&cBinop_pSq5tvfx, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_R96IYYBo, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NWtpJkUM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_cTDHmy6Q, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_61s11ttn, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Fy3jDNph, 0.0f);
  numBytes += hTable_init(&hTable_CqZa4dOv, 256);
  numBytes += cTabhead_init(&cTabhead_IPF5ofO5, &hTable_CqZa4dOv);
  numBytes += cVar_init_s(&cVar_kbwKxudN, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_PTC8FvhY, 16.364f);
  numBytes += cDelay_init(this, &cDelay_qxKqVmA3, 0.0f);
  numBytes += cBinop_init(&cBinop_tjvTFoI5, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_vTpr4f1Q, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nzwmj45j, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_PRSeWIjR, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_7AWI6Z7Z, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fQ1jdQnd, 0.0f);
  numBytes += hTable_init(&hTable_Hl9ouB9e, 256);
  numBytes += cTabhead_init(&cTabhead_uCDU8DiK, &hTable_Hl9ouB9e);
  numBytes += cVar_init_s(&cVar_tYwdfKC4, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_WQ6ckqwV, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_6ortthpd, 0.0f);
  numBytes += cBinop_init(&cBinop_Y7OulpxK, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_DU24dBu0, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9cd5tGvX, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6PRLHJST, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_sjDaXDm8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_c7xMRkPh, 0.0f);
  numBytes += hTable_init(&hTable_mVQXDqrJ, 256);
  numBytes += cTabhead_init(&cTabhead_5OCkNgOM, &hTable_mVQXDqrJ);
  numBytes += cVar_init_s(&cVar_BHbgXlxj, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_lBcoTXiy, 7.645f);
  numBytes += cDelay_init(this, &cDelay_h6mOJgro, 0.0f);
  numBytes += cBinop_init(&cBinop_LdhRhKO0, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_GvVGMMn9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_h9jelHh7, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ZisK3F68, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_ZfSPXr3T, 0.0f);
  numBytes += cVar_init_f(&cVar_475jASrs, 0.0f);
  numBytes += cPack_init(&cPack_xQKMj2Cy, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_ha3HZMDR, 22050.0f);
  numBytes += cBinop_init(&cBinop_VqHIW0m1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_x6e8wN31, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Pf9CTUyK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_py3ZK261, 22050.0f);
  numBytes += cBinop_init(&cBinop_7iAViFwZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GZjrIoYq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sc8QRQ1L, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_p0V8mYsc, 22050.0f);
  numBytes += cBinop_init(&cBinop_7xdkIxee, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9x8oP7Qq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lVw1x0QF, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_zayFWd6Q, 0.0f);
  numBytes += cVar_init_f(&cVar_yAnfxD7C, 1000.0f);
  numBytes += cBinop_init(&cBinop_tp6TIjc6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2HYqYUV3, 0.0f);
  numBytes += cVar_init_f(&cVar_8Jc5ghAm, 0.0f);
  numBytes += cIf_init(&cIf_HMvwWhqw, false);
  numBytes += cDelay_init(this, &cDelay_PFYEcAlV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mOiWrE50, 0.0f);
  numBytes += hTable_init(&hTable_CGqfSKGI, 256);
  numBytes += cTabhead_init(&cTabhead_l59eVvd7, &hTable_CGqfSKGI);
  numBytes += cVar_init_s(&cVar_hHH8mEMQ, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_WBYcI5GO, 150.0f);
  numBytes += cDelay_init(this, &cDelay_nEotHceT, 0.0f);
  numBytes += cBinop_init(&cBinop_tngAvvZI, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_SwgYw1Am, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_cLYrA2zp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_oUqEXHhX, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_BVCti94y, 0.0f);
  numBytes += cVar_init_f(&cVar_j2HEoNIl, 0.0f);
  numBytes += cVar_init_f(&cVar_tbKx8pA1, 0.0f);
  numBytes += cVar_init_f(&cVar_KoPqWL1n, 0.0f);
  numBytes += cVar_init_f(&cVar_4DQkKYwK, 0.0f);
  numBytes += cVar_init_f(&cVar_r0lx1Kec, 0.0f);
  numBytes += cIf_init(&cIf_qrv9niaV, false);
  numBytes += cVar_init_f(&cVar_Di8H8Ty7, 0.0f);
  numBytes += cIf_init(&cIf_a2oqWU0F, false);
  numBytes += cSlice_init(&cSlice_iwTckHZX, 1, -1);
  numBytes += cSlice_init(&cSlice_IBlNnetp, 1, -1);
  numBytes += cVar_init_f(&cVar_TJQq2K5k, 0.0f);
  numBytes += cIf_init(&cIf_D3RtrD0a, false);
  numBytes += cBinop_init(&cBinop_dMJkmgrs, 0.0f); // __neq
  numBytes += cIf_init(&cIf_0F47aLpB, false);
  numBytes += cIf_init(&cIf_rnAvuRed, false);
  numBytes += cIf_init(&cIf_DtELNm5Z, false);
  numBytes += cIf_init(&cIf_4973xQPn, true);
  numBytes += cIf_init(&cIf_GUN4WcUy, false);
  numBytes += sVarf_init(&sVarf_ev7W7Fie, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_2pZWL2hY, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_7yFkJW6y, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ymHTXyPK, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ERibUBT7, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_hau0OBsI, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TQKWY23o, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_CNZxVeAl, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_HfSV1rv8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_lJKuuL5u, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_MEzmc73m, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XTffoJ45, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_dRWfjwQ0, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_oOxRVP8O);
  cPack_free(&cPack_B6Onpznb);
  hTable_free(&hTable_LRRkcF7J);
  hTable_free(&hTable_HpTetOee);
  hTable_free(&hTable_0a2W8LKT);
  hTable_free(&hTable_whBMTTMF);
  hTable_free(&hTable_pHy8DdDl);
  cPack_free(&cPack_UNmOIkwS);
  cPack_free(&cPack_jVYDFhRL);
  hTable_free(&hTable_qSFowkX0);
  hTable_free(&hTable_vltz66uy);
  hTable_free(&hTable_KZZX2aen);
  hTable_free(&hTable_CqZa4dOv);
  hTable_free(&hTable_Hl9ouB9e);
  hTable_free(&hTable_mVQXDqrJ);
  cPack_free(&cPack_xQKMj2Cy);
  hTable_free(&hTable_CGqfSKGI);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_LRRkcF7J; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_HpTetOee; // del-1052-del1
    case 0xA2AC524D: return &hTable_0a2W8LKT; // del-1052-del2
    case 0xE36A35B: return &hTable_whBMTTMF; // del-1052-del3
    case 0x48CE0509: return &hTable_pHy8DdDl; // del-1052-del4
    case 0xE34D6E72: return &hTable_qSFowkX0; // del-1052-ref1
    case 0x6A1027AB: return &hTable_vltz66uy; // del-1052-ref2
    case 0xA37C6D49: return &hTable_KZZX2aen; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_CqZa4dOv; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_Hl9ouB9e; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_mVQXDqrJ; // del-1052-ref5
    case 0xED65564F: return &hTable_CGqfSKGI; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_emJwa5yr_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QVkt4wEi_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HNLJRgiH_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eT2cHFC2_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ANXHegV7_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZXpglU67_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ei0OBn51_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SXlY6XOk_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DZbXOBVN_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7wnATPM1_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7yKVXtb7_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pIWxbU7c_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aE1Sk30e_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OKGH1aHv_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j6rBFqld_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lOYjLDod_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JTWmXBUC_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ArJ44XwM_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Kn6MXJ8Z_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0ITo3QOI_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FtBOPv9A_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_67PYWRIT_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pz0No5CA_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eSRPWwuW_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_ecGbh7Pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_jzfqo560_sendMessage);
}

void Heavy_ChaffVerb::cVar_6udZ4HDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_wT6iHAek_sendMessage);
}

void Heavy_ChaffVerb::cPack_oOxRVP8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_oqGF3J4a, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_Yi7gzrqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T19lDVAO, 0, m, &cVar_T19lDVAO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DA52khk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_Yi7gzrqt_sendMessage);
}

void Heavy_ChaffVerb::cVar_T19lDVAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ija23afH_sendMessage);
}

void Heavy_ChaffVerb::cPack_B6Onpznb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_s9rLL2Zw, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_2avIbLMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_3cwfJTZF_sendMessage);
}

void Heavy_ChaffVerb::cVar_bvxoc1AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_0VjlSm5H, 0, m);
}

void Heavy_ChaffVerb::cMsg_kcXx7fLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2uSqzw9d_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2uSqzw9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9cv4WB9X_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3Xmaj6wZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3Xmaj6wZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hcpx75Mj, 0, m, &cDelay_Hcpx75Mj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Xmaj6wZ, 0, m, &cDelay_3Xmaj6wZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4fx4BH2w, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Hcpx75Mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Hcpx75Mj, m);
  cMsg_kTelGLMK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_IXEwxUNN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PrtEgQqo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_C5ROpFni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vjjgIKQn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LRRkcF7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zclCYb5N_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Xmaj6wZ, 2, m, &cDelay_3Xmaj6wZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCzGiwdc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vjjgIKQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LRRkcF7J, 0, m, &hTable_LRRkcF7J_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9cv4WB9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_C5ROpFni_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kTelGLMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LRRkcF7J, 0, m, &hTable_LRRkcF7J_sendMessage);
}

void Heavy_ChaffVerb::cCast_iCzGiwdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3Xmaj6wZ, 0, m, &cDelay_3Xmaj6wZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zclCYb5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hcpx75Mj, 2, m, &cDelay_Hcpx75Mj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PrtEgQqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4fx4BH2w, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_YJQH37gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XZaPqEFU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XZaPqEFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8uEiaG0i_sendMessage);
}

void Heavy_ChaffVerb::cVar_1Pls3hDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LyrXfIYX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_jpA9g1IE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7QC8tkS0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uXOp2dFT, m);
}

void Heavy_ChaffVerb::cBinop_8uEiaG0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0WZR9ohu, m);
}

void Heavy_ChaffVerb::cMsg_LyrXfIYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jpA9g1IE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7QC8tkS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_go125gOo, m);
}

void Heavy_ChaffVerb::cMsg_2UoO3jlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZW2Y9i2z_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZW2Y9i2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HlollCVG_sendMessage);
}

void Heavy_ChaffVerb::cVar_vW9nhsrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TsNN4y51_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_DDbanNjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CjAqbHEC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zwp2llak, m);
}

void Heavy_ChaffVerb::cBinop_HlollCVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bdp4hO8E, m);
}

void Heavy_ChaffVerb::cMsg_TsNN4y51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DDbanNjU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CjAqbHEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6wjKPV7N, m);
}

void Heavy_ChaffVerb::cBinop_GoaypJDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bvxoc1AY, 0, m, &cVar_bvxoc1AY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0RgdKmn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_INntfOWN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s5ycDWci_sendMessage);
}

void Heavy_ChaffVerb::cCast_s5ycDWci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GoaypJDz, HV_BINOP_DIVIDE, 0, m, &cBinop_GoaypJDz_sendMessage);
}

void Heavy_ChaffVerb::cCast_INntfOWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GoaypJDz, HV_BINOP_DIVIDE, 1, m, &cBinop_GoaypJDz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ija23afH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8rIUb9Xs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jzfqo560_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_DA52khk1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8rIUb9Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GoaypJDz, HV_BINOP_DIVIDE, 0, m, &cBinop_GoaypJDz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3cwfJTZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_B6Onpznb, 0, m, &cPack_B6Onpznb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wT6iHAek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_0RgdKmn6_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_oOxRVP8O, 0, m, &cPack_oOxRVP8O_sendMessage);
}

void Heavy_ChaffVerb::cUnop_w2PNROKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rnAvuRed, 0, m, &cIf_rnAvuRed_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_UERDvgeh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hjBcaDjG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n99lwb6q_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HG9N1xLl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_hjBcaDjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDIf1Jzl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_n99lwb6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L3c3KXCw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_HG9N1xLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lh4WxEZa_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_oFtSjkRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qiGv1hop_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qiGv1hop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xhgCbjv1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Nae4pOpS_sendMessage);
}

void Heavy_ChaffVerb::cVar_KomC7zOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_HZ3cv6jT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p5tx50YU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JqNt5NSl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JqNt5NSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jFK3ytzX, HV_BINOP_DIVIDE, 1, m, &cBinop_jFK3ytzX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xhgCbjv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TcqC5IwL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TcqC5IwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_APXmZaAy, m);
}

void Heavy_ChaffVerb::cMsg_B5qeGLW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2NTHRzYY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2NTHRzYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oFtSjkRs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nae4pOpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QkBR6cn3, m);
}

void Heavy_ChaffVerb::cBinop_HZ3cv6jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_7xDOMNDy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7xDOMNDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jFK3ytzX, HV_BINOP_DIVIDE, 0, m, &cBinop_jFK3ytzX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jFK3ytzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B5qeGLW1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_QO7lhFWO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2Q5G3UDe, 0, m, &cSlice_2Q5G3UDe_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_WZc0GDv2, 0, m, &cRandom_WZc0GDv2_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_JEk4lt0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_sAPfi4kI_sendMessage);
}

void Heavy_ChaffVerb::cUnop_sAPfi4kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_SxbpIqlF_sendMessage);
}

void Heavy_ChaffVerb::cRandom_WZc0GDv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_JEk4lt0i_sendMessage);
}

void Heavy_ChaffVerb::cSlice_2Q5G3UDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_WZc0GDv2, 1, m, &cRandom_WZc0GDv2_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_IoHipF4B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_2OhOwlQQ_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_2OhOwlQQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HMDl9jGy_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_MAIZDTxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MAIZDTxL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAIZDTxL, 0, m, &cDelay_MAIZDTxL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2HYqYUV3, 0, m, &cVar_2HYqYUV3_sendMessage);
}

void Heavy_ChaffVerb::cCast_HMDl9jGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2OhOwlQQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAIZDTxL, 0, m, &cDelay_MAIZDTxL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2HYqYUV3, 0, m, &cVar_2HYqYUV3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KFoQ1NoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L53M5NsU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_L53M5NsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eyAEOFEb_sendMessage);
}

void Heavy_ChaffVerb::cVar_gTpuD0JE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAyoHXKj, HV_BINOP_MULTIPLY, 0, m, &cBinop_DAyoHXKj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2OhOwlQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAIZDTxL, 0, m, &cDelay_MAIZDTxL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OyjpFe3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAIZDTxL, 2, m, &cDelay_MAIZDTxL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eyAEOFEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAyoHXKj, HV_BINOP_MULTIPLY, 1, m, &cBinop_DAyoHXKj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DAyoHXKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_OyjpFe3D_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_nQeYA8Dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgPQ5zfj, HV_BINOP_SUBTRACT, 0, m, &cBinop_VgPQ5zfj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HHwDKevx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cqmn6fLz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Cqmn6fLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6pPYGZUf_sendMessage);
}

void Heavy_ChaffVerb::cVar_MWiNZmoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rKIpo1F6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_exXkygV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_exXkygV6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ozma2OT, 0, m, &cDelay_1Ozma2OT_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BoWRiEAT, 0, m, &sTabread_BoWRiEAT_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1Ozma2OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Ozma2OT, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BoWRiEAT, 0, m, &sTabread_BoWRiEAT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ozma2OT, 0, m, &cDelay_1Ozma2OT_sendMessage);
}

void Heavy_ChaffVerb::sTabread_BoWRiEAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2NqXt2OV, HV_BINOP_SUBTRACT, 0, m, &cBinop_2NqXt2OV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_10ZB6evT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qdvI7DSp, HV_BINOP_MAX, 0, m, &cBinop_qdvI7DSp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6pPYGZUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_10ZB6evT, HV_BINOP_MULTIPLY, 0, m, &cBinop_10ZB6evT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VgPQ5zfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nzkzUSXq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BoWRiEAT, 0, m, &sTabread_BoWRiEAT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i1cfppbr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CkgSvUZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2NqXt2OV, HV_BINOP_SUBTRACT, 1, m, &cBinop_2NqXt2OV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ozma2OT, 2, m, &cDelay_1Ozma2OT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rKIpo1F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CkgSvUZR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nzkzUSXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_exXkygV6, 0, m, &cDelay_exXkygV6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ozma2OT, 0, m, &cDelay_1Ozma2OT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CA5iR72e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_qdvI7DSp, HV_BINOP_MAX, 1, m, &cBinop_qdvI7DSp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qdvI7DSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgPQ5zfj, HV_BINOP_SUBTRACT, 1, m, &cBinop_VgPQ5zfj_sendMessage);
}

void Heavy_ChaffVerb::cCast_i1cfppbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_exXkygV6, 0, m, &cDelay_exXkygV6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3TsVOKT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_exXkygV6, 2, m, &cDelay_exXkygV6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2NqXt2OV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3TsVOKT4_sendMessage);
}

void Heavy_ChaffVerb::cCast_yTLv7Qvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MWiNZmoj, 0, m, &cVar_MWiNZmoj_sendMessage);
  cMsg_HHwDKevx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nQeYA8Dc, 0, m, &cTabhead_nQeYA8Dc_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_6YtNdUPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g6qIFpQq, HV_BINOP_SUBTRACT, 0, m, &cBinop_g6qIFpQq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SfGZkofv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YElW5Hov_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YElW5Hov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fIIZCUAB_sendMessage);
}

void Heavy_ChaffVerb::cVar_bSLZvrQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5mQulXd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_EHXWv40U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EHXWv40U, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u9wwaf1U, 0, m, &cDelay_u9wwaf1U_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IYp1yUn7, 0, m, &sTabread_IYp1yUn7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_u9wwaf1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u9wwaf1U, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IYp1yUn7, 0, m, &sTabread_IYp1yUn7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u9wwaf1U, 0, m, &cDelay_u9wwaf1U_sendMessage);
}

void Heavy_ChaffVerb::sTabread_IYp1yUn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_pRr67sAd, HV_BINOP_SUBTRACT, 0, m, &cBinop_pRr67sAd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_B65xtonF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fFEte2XA, HV_BINOP_MAX, 0, m, &cBinop_fFEte2XA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fIIZCUAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B65xtonF, HV_BINOP_MULTIPLY, 0, m, &cBinop_B65xtonF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_g6qIFpQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zi70Ub1z_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_IYp1yUn7, 0, m, &sTabread_IYp1yUn7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8dz3EKQl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_V8XHgW9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pRr67sAd, HV_BINOP_SUBTRACT, 1, m, &cBinop_pRr67sAd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u9wwaf1U, 2, m, &cDelay_u9wwaf1U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_P5mQulXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_V8XHgW9x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Zi70Ub1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EHXWv40U, 0, m, &cDelay_EHXWv40U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u9wwaf1U, 0, m, &cDelay_u9wwaf1U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WbxrnGdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_fFEte2XA, HV_BINOP_MAX, 1, m, &cBinop_fFEte2XA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fFEte2XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g6qIFpQq, HV_BINOP_SUBTRACT, 1, m, &cBinop_g6qIFpQq_sendMessage);
}

void Heavy_ChaffVerb::cCast_8dz3EKQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EHXWv40U, 0, m, &cDelay_EHXWv40U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MCtrhHaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EHXWv40U, 2, m, &cDelay_EHXWv40U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pRr67sAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MCtrhHaH_sendMessage);
}

void Heavy_ChaffVerb::cCast_jU42kNo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bSLZvrQH, 0, m, &cVar_bSLZvrQH_sendMessage);
  cMsg_SfGZkofv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6YtNdUPX, 0, m, &cTabhead_6YtNdUPX_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_0ZlMKHuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtFOau7t, HV_BINOP_SUBTRACT, 0, m, &cBinop_BtFOau7t_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pE9bKwAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DnpgF8Jw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DnpgF8Jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4m0FfQA6_sendMessage);
}

void Heavy_ChaffVerb::cVar_VG98i2zS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qFX3USej_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_TFyItTPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TFyItTPg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y57S2Ylp, 0, m, &cDelay_y57S2Ylp_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BKw3EDjM, 0, m, &sTabread_BKw3EDjM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_y57S2Ylp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y57S2Ylp, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BKw3EDjM, 0, m, &sTabread_BKw3EDjM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y57S2Ylp, 0, m, &cDelay_y57S2Ylp_sendMessage);
}

void Heavy_ChaffVerb::sTabread_BKw3EDjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_zZwTfc55, HV_BINOP_SUBTRACT, 0, m, &cBinop_zZwTfc55_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_jFznnvz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EHFb1bL5, HV_BINOP_MAX, 0, m, &cBinop_EHFb1bL5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4m0FfQA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jFznnvz5, HV_BINOP_MULTIPLY, 0, m, &cBinop_jFznnvz5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BtFOau7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8zxP49Db_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BKw3EDjM, 0, m, &sTabread_BKw3EDjM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l83rFEmH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Y9ZLvU82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zZwTfc55, HV_BINOP_SUBTRACT, 1, m, &cBinop_zZwTfc55_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y57S2Ylp, 2, m, &cDelay_y57S2Ylp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qFX3USej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y9ZLvU82_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8zxP49Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TFyItTPg, 0, m, &cDelay_TFyItTPg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_y57S2Ylp, 0, m, &cDelay_y57S2Ylp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NJhpiO0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_EHFb1bL5, HV_BINOP_MAX, 1, m, &cBinop_EHFb1bL5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EHFb1bL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtFOau7t, HV_BINOP_SUBTRACT, 1, m, &cBinop_BtFOau7t_sendMessage);
}

void Heavy_ChaffVerb::cCast_l83rFEmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TFyItTPg, 0, m, &cDelay_TFyItTPg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JuVoeDX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TFyItTPg, 2, m, &cDelay_TFyItTPg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zZwTfc55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JuVoeDX7_sendMessage);
}

void Heavy_ChaffVerb::cCast_Vx9ESBAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VG98i2zS, 0, m, &cVar_VG98i2zS_sendMessage);
  cMsg_pE9bKwAz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_0ZlMKHuY, 0, m, &cTabhead_0ZlMKHuY_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_jXiMF1Vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sZ9CiWnV, HV_BINOP_SUBTRACT, 0, m, &cBinop_sZ9CiWnV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1boz8Av8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_abDTfFJz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_abDTfFJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vRVpKlBc_sendMessage);
}

void Heavy_ChaffVerb::cVar_v7FY8Fh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oMbboGB6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_AHVsc7xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AHVsc7xf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykQ0qV9C, 0, m, &cDelay_ykQ0qV9C_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5QalpX1l, 0, m, &sTabread_5QalpX1l_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ykQ0qV9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ykQ0qV9C, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5QalpX1l, 0, m, &sTabread_5QalpX1l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykQ0qV9C, 0, m, &cDelay_ykQ0qV9C_sendMessage);
}

void Heavy_ChaffVerb::sTabread_5QalpX1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kgRDKURo, HV_BINOP_SUBTRACT, 0, m, &cBinop_kgRDKURo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_iopSyaSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EulVszee, HV_BINOP_MAX, 0, m, &cBinop_EulVszee_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vRVpKlBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iopSyaSk, HV_BINOP_MULTIPLY, 0, m, &cBinop_iopSyaSk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sZ9CiWnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mTdJKMo3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5QalpX1l, 0, m, &sTabread_5QalpX1l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XC8Vuge8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_B6ALHtDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgRDKURo, HV_BINOP_SUBTRACT, 1, m, &cBinop_kgRDKURo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykQ0qV9C, 2, m, &cDelay_ykQ0qV9C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oMbboGB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B6ALHtDv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mTdJKMo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AHVsc7xf, 0, m, &cDelay_AHVsc7xf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ykQ0qV9C, 0, m, &cDelay_ykQ0qV9C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5iOHH4as_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_EulVszee, HV_BINOP_MAX, 1, m, &cBinop_EulVszee_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EulVszee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sZ9CiWnV, HV_BINOP_SUBTRACT, 1, m, &cBinop_sZ9CiWnV_sendMessage);
}

void Heavy_ChaffVerb::cCast_XC8Vuge8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AHVsc7xf, 0, m, &cDelay_AHVsc7xf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JN4tU9jC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AHVsc7xf, 2, m, &cDelay_AHVsc7xf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kgRDKURo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JN4tU9jC_sendMessage);
}

void Heavy_ChaffVerb::cCast_iNLAPskN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v7FY8Fh3, 0, m, &cVar_v7FY8Fh3_sendMessage);
  cMsg_1boz8Av8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jXiMF1Vt, 0, m, &cTabhead_jXiMF1Vt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0zhCfikK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0DSRuIy5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0DSRuIy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UChuBo4r_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2NVEf02W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2NVEf02W, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NRvpLjp3, 0, m, &cDelay_NRvpLjp3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NVEf02W, 0, m, &cDelay_2NVEf02W_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WwHAjcJL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_NRvpLjp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NRvpLjp3, m);
  cMsg_iUtohmzR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HgfhXxd7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_exT04jLX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_CEuzWDni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tEZHLlUF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_HpTetOee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HGOv01VS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NVEf02W, 2, m, &cDelay_2NVEf02W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A2O2gkBp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tEZHLlUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_HpTetOee, 0, m, &hTable_HpTetOee_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UChuBo4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_CEuzWDni_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iUtohmzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_HpTetOee, 0, m, &hTable_HpTetOee_sendMessage);
}

void Heavy_ChaffVerb::cCast_A2O2gkBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NVEf02W, 0, m, &cDelay_2NVEf02W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HGOv01VS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NRvpLjp3, 2, m, &cDelay_NRvpLjp3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_exT04jLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WwHAjcJL, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_yMqtiEPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RkhWFfyx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RkhWFfyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_haD0AvCy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Nt0a3iZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Nt0a3iZb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uTd9nqRw, 0, m, &cDelay_uTd9nqRw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nt0a3iZb, 0, m, &cDelay_Nt0a3iZb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PC3Un7ur, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_uTd9nqRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uTd9nqRw, m);
  cMsg_wSA3kE5m_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_3fpLQm2L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fNdOFVSu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_kTYieLQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iFNddr8Q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_0a2W8LKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CbYrM3Yl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nt0a3iZb, 2, m, &cDelay_Nt0a3iZb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aY3kDI7S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iFNddr8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0a2W8LKT, 0, m, &hTable_0a2W8LKT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_haD0AvCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_kTYieLQy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wSA3kE5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0a2W8LKT, 0, m, &hTable_0a2W8LKT_sendMessage);
}

void Heavy_ChaffVerb::cCast_aY3kDI7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nt0a3iZb, 0, m, &cDelay_Nt0a3iZb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CbYrM3Yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uTd9nqRw, 2, m, &cDelay_uTd9nqRw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fNdOFVSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PC3Un7ur, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_FjdaW0Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TmUfSLJC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TmUfSLJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_j9gc1aSg_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MWYzCfCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MWYzCfCk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hSDA3zhN, 0, m, &cDelay_hSDA3zhN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWYzCfCk, 0, m, &cDelay_MWYzCfCk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pAP82yt1, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hSDA3zhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hSDA3zhN, m);
  cMsg_9gkjqwJi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_XBKM8o0G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_WxbanugR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_P15mTIhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kIZKeRVW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_whBMTTMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MZBzW8Yu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWYzCfCk, 2, m, &cDelay_MWYzCfCk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWNmE7dr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kIZKeRVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_whBMTTMF, 0, m, &hTable_whBMTTMF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j9gc1aSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_P15mTIhh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9gkjqwJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_whBMTTMF, 0, m, &hTable_whBMTTMF_sendMessage);
}

void Heavy_ChaffVerb::cCast_vWNmE7dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWYzCfCk, 0, m, &cDelay_MWYzCfCk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MZBzW8Yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hSDA3zhN, 2, m, &cDelay_hSDA3zhN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WxbanugR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pAP82yt1, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_XWadHjB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dWevqiBT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dWevqiBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wgsePqoG_sendMessage);
}

void Heavy_ChaffVerb::cDelay_KCpTgXxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KCpTgXxP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ybcoGYS6, 0, m, &cDelay_ybcoGYS6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KCpTgXxP, 0, m, &cDelay_KCpTgXxP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y6JA3G1e, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_ybcoGYS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ybcoGYS6, m);
  cMsg_o8s379sM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_A8mxhc2G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KLD2Zwnz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_WKC2QRi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JE4MDzLP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_pHy8DdDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WsJWqRJ7_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KCpTgXxP, 2, m, &cDelay_KCpTgXxP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OkvdqjrC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JE4MDzLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pHy8DdDl, 0, m, &hTable_pHy8DdDl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wgsePqoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_WKC2QRi2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_o8s379sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pHy8DdDl, 0, m, &hTable_pHy8DdDl_sendMessage);
}

void Heavy_ChaffVerb::cCast_OkvdqjrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KCpTgXxP, 0, m, &cDelay_KCpTgXxP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WsJWqRJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ybcoGYS6, 2, m, &cDelay_ybcoGYS6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KLD2Zwnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Y6JA3G1e, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_UNmOIkwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_1eMOLNSD, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_jVYDFhRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_dTjgUxY3, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_rVNWkkdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kV2LWPVx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kV2LWPVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_PHSig2Q1_sendMessage);
}

void Heavy_ChaffVerb::cVar_IWTnBYd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htqUAocQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_htqUAocQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qGparK4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9KEZyLFo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9KEZyLFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x5vkbLwu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_htqUAocQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_blX2poEA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YZG4URqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htqUAocQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_htqUAocQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x5vkbLwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YZG4URqZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_blX2poEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VeIt2krC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VeIt2krC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rgURDG8j_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5vDhtPJB, m);
}

void Heavy_ChaffVerb::cBinop_rgURDG8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oO75cqZB, m);
}

void Heavy_ChaffVerb::cVar_3cgJmL8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_hWNvx1i4_sendMessage);
}

void Heavy_ChaffVerb::cVar_iiayiZRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rVNWkkdQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_b1OFOz1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_dGe36C9U_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_x93Q50IA, 0, m, &cIf_x93Q50IA_sendMessage);
}

void Heavy_ChaffVerb::cVar_HW7U9ZHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dhJPpSEo_sendMessage);
}

void Heavy_ChaffVerb::cIf_x93Q50IA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6sSlmcMK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZfSPXr3T, 0, m, &cVar_ZfSPXr3T_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_dGe36C9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x93Q50IA, 1, m, &cIf_x93Q50IA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dhJPpSEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_73LTISQv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_73LTISQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_475jASrs, 0, m, &cVar_475jASrs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_orYXb1Bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HBQ91Vz8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HBQ91Vz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rsnqE6Iq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_uThYhCDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uThYhCDM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWw1ciDS, 0, m, &cDelay_sWw1ciDS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uThYhCDM, 0, m, &cDelay_uThYhCDM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_K0uXIN5h, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_sWw1ciDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sWw1ciDS, m);
  cMsg_oQjg0FHL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_XyeU0LmV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_V7UChskA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VZOMB4EB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ukXjmt6V_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_qSFowkX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Am0GggxP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uThYhCDM, 2, m, &cDelay_uThYhCDM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oLXNY8ZT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ukXjmt6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_qSFowkX0, 0, m, &hTable_qSFowkX0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rsnqE6Iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_VZOMB4EB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oQjg0FHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_qSFowkX0, 0, m, &hTable_qSFowkX0_sendMessage);
}

void Heavy_ChaffVerb::cCast_oLXNY8ZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uThYhCDM, 0, m, &cDelay_uThYhCDM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Am0GggxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sWw1ciDS, 2, m, &cDelay_sWw1ciDS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V7UChskA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_K0uXIN5h, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_OzI7Xhu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DqLoHcLm, HV_BINOP_SUBTRACT, 0, m, &cBinop_DqLoHcLm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mCwKpdd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SlaOEuvh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SlaOEuvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jQgJgk8X_sendMessage);
}

void Heavy_ChaffVerb::cVar_PouJAbr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fVzX12xb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_8rL6pUAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8rL6pUAe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5Z4L2zY, 0, m, &cDelay_b5Z4L2zY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UMrkrym0, 0, m, &sTabread_UMrkrym0_sendMessage);
}

void Heavy_ChaffVerb::cDelay_b5Z4L2zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b5Z4L2zY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UMrkrym0, 0, m, &sTabread_UMrkrym0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5Z4L2zY, 0, m, &cDelay_b5Z4L2zY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_UMrkrym0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VtJXpr2Y, HV_BINOP_SUBTRACT, 0, m, &cBinop_VtJXpr2Y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_FZBt8MbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_61iGpHBC, HV_BINOP_MAX, 0, m, &cBinop_61iGpHBC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jQgJgk8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZBt8MbL, HV_BINOP_MULTIPLY, 0, m, &cBinop_FZBt8MbL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DqLoHcLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HexcTF5J_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UMrkrym0, 0, m, &sTabread_UMrkrym0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PxqXByTA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SO0HS9xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VtJXpr2Y, HV_BINOP_SUBTRACT, 1, m, &cBinop_VtJXpr2Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5Z4L2zY, 2, m, &cDelay_b5Z4L2zY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fVzX12xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SO0HS9xZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HexcTF5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8rL6pUAe, 0, m, &cDelay_8rL6pUAe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5Z4L2zY, 0, m, &cDelay_b5Z4L2zY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XOVp3GPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_61iGpHBC, HV_BINOP_MAX, 1, m, &cBinop_61iGpHBC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_61iGpHBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DqLoHcLm, HV_BINOP_SUBTRACT, 1, m, &cBinop_DqLoHcLm_sendMessage);
}

void Heavy_ChaffVerb::cCast_PxqXByTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8rL6pUAe, 0, m, &cDelay_8rL6pUAe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OWGQf8AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8rL6pUAe, 2, m, &cDelay_8rL6pUAe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VtJXpr2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OWGQf8AJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_eu7QW3fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PouJAbr4, 0, m, &cVar_PouJAbr4_sendMessage);
  cMsg_mCwKpdd7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OzI7Xhu9, 0, m, &cTabhead_OzI7Xhu9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_usTKcGH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tQKnqwVd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tQKnqwVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Et66QgfC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Rb0aoBWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Rb0aoBWx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_loxPmR17, 0, m, &cDelay_loxPmR17_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rb0aoBWx, 0, m, &cDelay_Rb0aoBWx_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVaU32Uj, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_loxPmR17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_loxPmR17, m);
  cMsg_StKKq2uU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_VzRbnAuu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_FVES5Tv0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8o1NwYpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJLogsLr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_vltz66uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YvzY8odj_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rb0aoBWx, 2, m, &cDelay_Rb0aoBWx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s5vDqT8R_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PJLogsLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_vltz66uy, 0, m, &hTable_vltz66uy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Et66QgfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_8o1NwYpf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_StKKq2uU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_vltz66uy, 0, m, &hTable_vltz66uy_sendMessage);
}

void Heavy_ChaffVerb::cCast_s5vDqT8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rb0aoBWx, 0, m, &cDelay_Rb0aoBWx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YvzY8odj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_loxPmR17, 2, m, &cDelay_loxPmR17_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FVES5Tv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVaU32Uj, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_3fIiqIPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcKPnwBU, HV_BINOP_SUBTRACT, 0, m, &cBinop_kcKPnwBU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vURJfGht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y6CY488H_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Y6CY488H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gSGJyjXq_sendMessage);
}

void Heavy_ChaffVerb::cVar_Pn9HIzjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mecP0stu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_oGq9isCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oGq9isCK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oadob5St, 0, m, &cDelay_oadob5St_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H5SZR1fn, 0, m, &sTabread_H5SZR1fn_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oadob5St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oadob5St, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H5SZR1fn, 0, m, &sTabread_H5SZR1fn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oadob5St, 0, m, &cDelay_oadob5St_sendMessage);
}

void Heavy_ChaffVerb::sTabread_H5SZR1fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_92RpitzW, HV_BINOP_SUBTRACT, 0, m, &cBinop_92RpitzW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_7HfvDIBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8QrPw7Bx, HV_BINOP_MAX, 0, m, &cBinop_8QrPw7Bx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gSGJyjXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7HfvDIBO, HV_BINOP_MULTIPLY, 0, m, &cBinop_7HfvDIBO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kcKPnwBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tjzd1xQS_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_H5SZR1fn, 0, m, &sTabread_H5SZR1fn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zTSLeMKN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dmAKpDqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_92RpitzW, HV_BINOP_SUBTRACT, 1, m, &cBinop_92RpitzW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oadob5St, 2, m, &cDelay_oadob5St_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mecP0stu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dmAKpDqI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tjzd1xQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oGq9isCK, 0, m, &cDelay_oGq9isCK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oadob5St, 0, m, &cDelay_oadob5St_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GpugSUnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8QrPw7Bx, HV_BINOP_MAX, 1, m, &cBinop_8QrPw7Bx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8QrPw7Bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcKPnwBU, HV_BINOP_SUBTRACT, 1, m, &cBinop_kcKPnwBU_sendMessage);
}

void Heavy_ChaffVerb::cCast_zTSLeMKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oGq9isCK, 0, m, &cDelay_oGq9isCK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9eNEB1GI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oGq9isCK, 2, m, &cDelay_oGq9isCK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_92RpitzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9eNEB1GI_sendMessage);
}

void Heavy_ChaffVerb::cCast_Zv2pQces_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pn9HIzjw, 0, m, &cVar_Pn9HIzjw_sendMessage);
  cMsg_vURJfGht_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3fIiqIPM, 0, m, &cTabhead_3fIiqIPM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G0dYoS4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SyZU3J6Z_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SyZU3J6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JFRjwU2U_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Sqd81UUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sqd81UUH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K7WU35lE, 0, m, &cDelay_K7WU35lE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sqd81UUH, 0, m, &cDelay_Sqd81UUH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DyikTmQA, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_K7WU35lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K7WU35lE, m);
  cMsg_gR3Bavre_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_s8Qs9QY6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_HOu6DNMP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9LsSzc1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KYumHYGc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_KZZX2aen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCyXYmxk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sqd81UUH, 2, m, &cDelay_Sqd81UUH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lXqhUDK9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KYumHYGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_KZZX2aen, 0, m, &hTable_KZZX2aen_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JFRjwU2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_9LsSzc1d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gR3Bavre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_KZZX2aen, 0, m, &hTable_KZZX2aen_sendMessage);
}

void Heavy_ChaffVerb::cCast_lXqhUDK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sqd81UUH, 0, m, &cDelay_Sqd81UUH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BCyXYmxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_K7WU35lE, 2, m, &cDelay_K7WU35lE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HOu6DNMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DyikTmQA, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_pubX3OCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R96IYYBo, HV_BINOP_SUBTRACT, 0, m, &cBinop_R96IYYBo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kxIHDoQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iQuJJXJr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_iQuJJXJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1DpYAJzU_sendMessage);
}

void Heavy_ChaffVerb::cVar_u17uO8S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXhxwIB7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_xybTaEZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xybTaEZ2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgbijApR, 0, m, &cDelay_sgbijApR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x30HpyjE, 0, m, &sTabread_x30HpyjE_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sgbijApR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sgbijApR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x30HpyjE, 0, m, &sTabread_x30HpyjE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgbijApR, 0, m, &cDelay_sgbijApR_sendMessage);
}

void Heavy_ChaffVerb::sTabread_x30HpyjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_cTDHmy6Q, HV_BINOP_SUBTRACT, 0, m, &cBinop_cTDHmy6Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_pSq5tvfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NWtpJkUM, HV_BINOP_MAX, 0, m, &cBinop_NWtpJkUM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1DpYAJzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pSq5tvfx, HV_BINOP_MULTIPLY, 0, m, &cBinop_pSq5tvfx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R96IYYBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vHzL65aM_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_x30HpyjE, 0, m, &sTabread_x30HpyjE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcaApIIU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Lj22cfvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cTDHmy6Q, HV_BINOP_SUBTRACT, 1, m, &cBinop_cTDHmy6Q_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgbijApR, 2, m, &cDelay_sgbijApR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aXhxwIB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Lj22cfvM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vHzL65aM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xybTaEZ2, 0, m, &cDelay_xybTaEZ2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sgbijApR, 0, m, &cDelay_sgbijApR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tEGHp8nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NWtpJkUM, HV_BINOP_MAX, 1, m, &cBinop_NWtpJkUM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NWtpJkUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R96IYYBo, HV_BINOP_SUBTRACT, 1, m, &cBinop_R96IYYBo_sendMessage);
}

void Heavy_ChaffVerb::cCast_YcaApIIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xybTaEZ2, 0, m, &cDelay_xybTaEZ2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JeEbxhxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xybTaEZ2, 2, m, &cDelay_xybTaEZ2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cTDHmy6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JeEbxhxW_sendMessage);
}

void Heavy_ChaffVerb::cCast_uunBNuty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u17uO8S7, 0, m, &cVar_u17uO8S7_sendMessage);
  cMsg_kxIHDoQP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_pubX3OCm, 0, m, &cTabhead_pubX3OCm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g2LO3srC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FLXVzOQ8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FLXVzOQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cetwItHr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_61s11ttn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_61s11ttn, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fy3jDNph, 0, m, &cDelay_Fy3jDNph_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_61s11ttn, 0, m, &cDelay_61s11ttn_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XgEPBFuq, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Fy3jDNph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fy3jDNph, m);
  cMsg_rbCEysyP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_C0aJuUay_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c7KxpNJa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wpTDv6MH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_libVE4XP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_CqZa4dOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E4Nipt8M_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_61s11ttn, 2, m, &cDelay_61s11ttn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Phq50KOT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_libVE4XP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CqZa4dOv, 0, m, &hTable_CqZa4dOv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cetwItHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_wpTDv6MH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rbCEysyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CqZa4dOv, 0, m, &hTable_CqZa4dOv_sendMessage);
}

void Heavy_ChaffVerb::cCast_Phq50KOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_61s11ttn, 0, m, &cDelay_61s11ttn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_E4Nipt8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fy3jDNph, 2, m, &cDelay_Fy3jDNph_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c7KxpNJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XgEPBFuq, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_IPF5ofO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vTpr4f1Q, HV_BINOP_SUBTRACT, 0, m, &cBinop_vTpr4f1Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IomwOMaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k83xGnfY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_k83xGnfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EDBvZr25_sendMessage);
}

void Heavy_ChaffVerb::cVar_kbwKxudN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j35PcXok_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_PTC8FvhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PTC8FvhY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxKqVmA3, 0, m, &cDelay_qxKqVmA3_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mXX5ho42, 0, m, &sTabread_mXX5ho42_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qxKqVmA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qxKqVmA3, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mXX5ho42, 0, m, &sTabread_mXX5ho42_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxKqVmA3, 0, m, &cDelay_qxKqVmA3_sendMessage);
}

void Heavy_ChaffVerb::sTabread_mXX5ho42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PRSeWIjR, HV_BINOP_SUBTRACT, 0, m, &cBinop_PRSeWIjR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_tjvTFoI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nzwmj45j, HV_BINOP_MAX, 0, m, &cBinop_nzwmj45j_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EDBvZr25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tjvTFoI5, HV_BINOP_MULTIPLY, 0, m, &cBinop_tjvTFoI5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vTpr4f1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sLTtz7CJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mXX5ho42, 0, m, &sTabread_mXX5ho42_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o2Ilqz8L_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EF9vkz7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRSeWIjR, HV_BINOP_SUBTRACT, 1, m, &cBinop_PRSeWIjR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxKqVmA3, 2, m, &cDelay_qxKqVmA3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_j35PcXok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EF9vkz7Z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sLTtz7CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PTC8FvhY, 0, m, &cDelay_PTC8FvhY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxKqVmA3, 0, m, &cDelay_qxKqVmA3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_osYIFwwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_nzwmj45j, HV_BINOP_MAX, 1, m, &cBinop_nzwmj45j_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nzwmj45j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vTpr4f1Q, HV_BINOP_SUBTRACT, 1, m, &cBinop_vTpr4f1Q_sendMessage);
}

void Heavy_ChaffVerb::cCast_o2Ilqz8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PTC8FvhY, 0, m, &cDelay_PTC8FvhY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XqJBzcqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PTC8FvhY, 2, m, &cDelay_PTC8FvhY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PRSeWIjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XqJBzcqO_sendMessage);
}

void Heavy_ChaffVerb::cCast_wqmPiQGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kbwKxudN, 0, m, &cVar_kbwKxudN_sendMessage);
  cMsg_IomwOMaU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IPF5ofO5, 0, m, &cTabhead_IPF5ofO5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B1z5Q4VV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k7EvwcWy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_k7EvwcWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zxr4N8mU_sendMessage);
}

void Heavy_ChaffVerb::cDelay_7AWI6Z7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7AWI6Z7Z, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fQ1jdQnd, 0, m, &cDelay_fQ1jdQnd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7AWI6Z7Z, 0, m, &cDelay_7AWI6Z7Z_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XjNCXCCx, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_fQ1jdQnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fQ1jdQnd, m);
  cMsg_31GpjrGx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_aDBwF4Qu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0fxaAXAx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_tH5mBrYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TyCOZFyc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Hl9ouB9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5zAye0ux_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7AWI6Z7Z, 2, m, &cDelay_7AWI6Z7Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PTQvloTw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TyCOZFyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Hl9ouB9e, 0, m, &hTable_Hl9ouB9e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zxr4N8mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_tH5mBrYn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_31GpjrGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Hl9ouB9e, 0, m, &hTable_Hl9ouB9e_sendMessage);
}

void Heavy_ChaffVerb::cCast_PTQvloTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7AWI6Z7Z, 0, m, &cDelay_7AWI6Z7Z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5zAye0ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_fQ1jdQnd, 2, m, &cDelay_fQ1jdQnd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0fxaAXAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XjNCXCCx, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_uCDU8DiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DU24dBu0, HV_BINOP_SUBTRACT, 0, m, &cBinop_DU24dBu0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cWLvY9Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z6abnGJH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Z6abnGJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_L8cytcgI_sendMessage);
}

void Heavy_ChaffVerb::cVar_tYwdfKC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vI4nbPHv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_WQ6ckqwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WQ6ckqwV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ortthpd, 0, m, &cDelay_6ortthpd_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Tr02v7aG, 0, m, &sTabread_Tr02v7aG_sendMessage);
}

void Heavy_ChaffVerb::cDelay_6ortthpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6ortthpd, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Tr02v7aG, 0, m, &sTabread_Tr02v7aG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ortthpd, 0, m, &cDelay_6ortthpd_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Tr02v7aG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6PRLHJST, HV_BINOP_SUBTRACT, 0, m, &cBinop_6PRLHJST_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Y7OulpxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cd5tGvX, HV_BINOP_MAX, 0, m, &cBinop_9cd5tGvX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L8cytcgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7OulpxK, HV_BINOP_MULTIPLY, 0, m, &cBinop_Y7OulpxK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DU24dBu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LYGX6EIJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Tr02v7aG, 0, m, &sTabread_Tr02v7aG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4iRCX14_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rMCtM5PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6PRLHJST, HV_BINOP_SUBTRACT, 1, m, &cBinop_6PRLHJST_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ortthpd, 2, m, &cDelay_6ortthpd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vI4nbPHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rMCtM5PA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LYGX6EIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQ6ckqwV, 0, m, &cDelay_WQ6ckqwV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ortthpd, 0, m, &cDelay_6ortthpd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hy38LkkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cd5tGvX, HV_BINOP_MAX, 1, m, &cBinop_9cd5tGvX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9cd5tGvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DU24dBu0, HV_BINOP_SUBTRACT, 1, m, &cBinop_DU24dBu0_sendMessage);
}

void Heavy_ChaffVerb::cCast_R4iRCX14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQ6ckqwV, 0, m, &cDelay_WQ6ckqwV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fQt90RFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQ6ckqwV, 2, m, &cDelay_WQ6ckqwV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6PRLHJST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fQt90RFM_sendMessage);
}

void Heavy_ChaffVerb::cCast_iqy1iyY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tYwdfKC4, 0, m, &cVar_tYwdfKC4_sendMessage);
  cMsg_cWLvY9Ec_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uCDU8DiK, 0, m, &cTabhead_uCDU8DiK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rUYKdLsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7g33YLxD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7g33YLxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fsncIhj6_sendMessage);
}

void Heavy_ChaffVerb::cDelay_sjDaXDm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sjDaXDm8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_c7xMRkPh, 0, m, &cDelay_c7xMRkPh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjDaXDm8, 0, m, &cDelay_sjDaXDm8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VtQhKxcn, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_c7xMRkPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c7xMRkPh, m);
  cMsg_XaaOgxhN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_yc0YHHki_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LAw1691c_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_NNHdZoeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F4IJPfXh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_mVQXDqrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tuMmeV1Y_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjDaXDm8, 2, m, &cDelay_sjDaXDm8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WqrHU9Wg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F4IJPfXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_mVQXDqrJ, 0, m, &hTable_mVQXDqrJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fsncIhj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_NNHdZoeJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XaaOgxhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_mVQXDqrJ, 0, m, &hTable_mVQXDqrJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_WqrHU9Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sjDaXDm8, 0, m, &cDelay_sjDaXDm8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tuMmeV1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_c7xMRkPh, 2, m, &cDelay_c7xMRkPh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LAw1691c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VtQhKxcn, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_5OCkNgOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GvVGMMn9, HV_BINOP_SUBTRACT, 0, m, &cBinop_GvVGMMn9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xZYbFLKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xGQdCzvR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xGQdCzvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cE16Z1Cz_sendMessage);
}

void Heavy_ChaffVerb::cVar_BHbgXlxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kc4DBaLQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_lBcoTXiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lBcoTXiy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6mOJgro, 0, m, &cDelay_h6mOJgro_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dMJfdbuF, 0, m, &sTabread_dMJfdbuF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_h6mOJgro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h6mOJgro, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dMJfdbuF, 0, m, &sTabread_dMJfdbuF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6mOJgro, 0, m, &cDelay_h6mOJgro_sendMessage);
}

void Heavy_ChaffVerb::sTabread_dMJfdbuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ZisK3F68, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZisK3F68_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LdhRhKO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h9jelHh7, HV_BINOP_MAX, 0, m, &cBinop_h9jelHh7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cE16Z1Cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdhRhKO0, HV_BINOP_MULTIPLY, 0, m, &cBinop_LdhRhKO0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GvVGMMn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTTy9Yma_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dMJfdbuF, 0, m, &sTabread_dMJfdbuF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MyeZUltC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ysM9hmwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZisK3F68, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZisK3F68_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6mOJgro, 2, m, &cDelay_h6mOJgro_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Kc4DBaLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ysM9hmwI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XTTy9Yma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lBcoTXiy, 0, m, &cDelay_lBcoTXiy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h6mOJgro, 0, m, &cDelay_h6mOJgro_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zAhpqgny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_h9jelHh7, HV_BINOP_MAX, 1, m, &cBinop_h9jelHh7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h9jelHh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GvVGMMn9, HV_BINOP_SUBTRACT, 1, m, &cBinop_GvVGMMn9_sendMessage);
}

void Heavy_ChaffVerb::cCast_MyeZUltC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lBcoTXiy, 0, m, &cDelay_lBcoTXiy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3rC2IuUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lBcoTXiy, 2, m, &cDelay_lBcoTXiy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZisK3F68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3rC2IuUa_sendMessage);
}

void Heavy_ChaffVerb::cCast_hBHd8bhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BHbgXlxj, 0, m, &cVar_BHbgXlxj_sendMessage);
  cMsg_xZYbFLKD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5OCkNgOM, 0, m, &cTabhead_5OCkNgOM_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZfSPXr3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IWTnBYd3, 0, m, &cVar_IWTnBYd3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ha3HZMDR, 0, m, &cVar_ha3HZMDR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_py3ZK261, 0, m, &cVar_py3ZK261_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p0V8mYsc, 0, m, &cVar_p0V8mYsc_sendMessage);
}

void Heavy_ChaffVerb::cVar_475jASrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_ufkkuzCq_sendMessage);
}

void Heavy_ChaffVerb::cPack_xQKMj2Cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_NA1DmgYx, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_ha3HZMDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VqHIW0m1, HV_BINOP_MULTIPLY, 0, m, &cBinop_VqHIW0m1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qduUvhHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4rZXE07f_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4rZXE07f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yg7MJJxd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_VqHIW0m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qOssjVpt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_atArv2Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VqHIW0m1, HV_BINOP_MULTIPLY, 1, m, &cBinop_VqHIW0m1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Yg7MJJxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_atArv2Az_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qOssjVpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BlbonMfu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BlbonMfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bsyIoXtd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Pf9CTUyK, m);
}

void Heavy_ChaffVerb::cBinop_bsyIoXtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x6e8wN31, m);
}

void Heavy_ChaffVerb::cVar_py3ZK261_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7iAViFwZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_7iAViFwZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wiSUTIWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sEWAln1Y_sendMessage);
}

void Heavy_ChaffVerb::cSystem_sEWAln1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x95E4aKF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_7iAViFwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JKUwPAo2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_P9aMABV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7iAViFwZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_7iAViFwZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x95E4aKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_P9aMABV9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JKUwPAo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IrttXLGY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IrttXLGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EdPlh42F_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sc8QRQ1L, m);
}

void Heavy_ChaffVerb::cBinop_EdPlh42F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GZjrIoYq, m);
}

void Heavy_ChaffVerb::cVar_p0V8mYsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7xdkIxee, HV_BINOP_MULTIPLY, 0, m, &cBinop_7xdkIxee_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HjyzjNf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g6zH3NqB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_g6zH3NqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JWlGpp1u_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_7xdkIxee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Dmmi4cPS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CrLw5W7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7xdkIxee, HV_BINOP_MULTIPLY, 1, m, &cBinop_7xdkIxee_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JWlGpp1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CrLw5W7u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dmmi4cPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tBJg2rAT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tBJg2rAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6Cht9Omr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lVw1x0QF, m);
}

void Heavy_ChaffVerb::cBinop_6Cht9Omr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9x8oP7Qq, m);
}

void Heavy_ChaffVerb::cBinop_PHSig2Q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_jVYDFhRL, 0, m, &cPack_jVYDFhRL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6sSlmcMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZfSPXr3T, 0, m, &cVar_ZfSPXr3T_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ufkkuzCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_xQKMj2Cy, 0, m, &cPack_xQKMj2Cy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hWNvx1i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_UNmOIkwS, 0, m, &cPack_UNmOIkwS_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_yS0Xohiz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_ueEBV7Gr_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_ueEBV7Gr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1BRTmj3g_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_zayFWd6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zayFWd6Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zayFWd6Q, 0, m, &cDelay_zayFWd6Q_sendMessage);
  cSwitchcase_QO7lhFWO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_1BRTmj3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ueEBV7Gr_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zayFWd6Q, 0, m, &cDelay_zayFWd6Q_sendMessage);
  cSwitchcase_QO7lhFWO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_cIdDZ3mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2HNXqKmc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2HNXqKmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9nCDOnOI_sendMessage);
}

void Heavy_ChaffVerb::cVar_yAnfxD7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tp6TIjc6, HV_BINOP_MULTIPLY, 0, m, &cBinop_tp6TIjc6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ueEBV7Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zayFWd6Q, 0, m, &cDelay_zayFWd6Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mJrCuS4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zayFWd6Q, 2, m, &cDelay_zayFWd6Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9nCDOnOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tp6TIjc6, HV_BINOP_MULTIPLY, 1, m, &cBinop_tp6TIjc6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tp6TIjc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_mJrCuS4O_sendMessage);
}

void Heavy_ChaffVerb::cVar_2HYqYUV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_IywhcCvo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_BgR05A1x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7oI9T88q_sendMessage);
}

void Heavy_ChaffVerb::cVar_8Jc5ghAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xT8iD6yK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_HMvwWhqw, 0, m, &cIf_HMvwWhqw_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jRGuBfTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pZWL2hY, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_2pZWL2hY_sendMessage);
}

void Heavy_ChaffVerb::cUnop_5JlJ5GnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pZWL2hY, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_2pZWL2hY_sendMessage);
}

void Heavy_ChaffVerb::cIf_HMvwWhqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_5JlJ5GnD_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_jRGuBfTX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xT8iD6yK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HMvwWhqw, 1, m, &cIf_HMvwWhqw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SShF5cLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W7auimcK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_W7auimcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_udL8UKIF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PFYEcAlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PFYEcAlV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mOiWrE50, 0, m, &cDelay_mOiWrE50_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PFYEcAlV, 0, m, &cDelay_PFYEcAlV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pQOGuKzg, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_mOiWrE50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mOiWrE50, m);
  cMsg_JCORFIIn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_elCf0inE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MRvyDH6X_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_dgTlsISu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wzdBq8vo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_CGqfSKGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8GwLqCqw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PFYEcAlV, 2, m, &cDelay_PFYEcAlV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rDPY2NsK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wzdBq8vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CGqfSKGI, 0, m, &hTable_CGqfSKGI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_udL8UKIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_dgTlsISu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JCORFIIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CGqfSKGI, 0, m, &hTable_CGqfSKGI_sendMessage);
}

void Heavy_ChaffVerb::cCast_rDPY2NsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PFYEcAlV, 0, m, &cDelay_PFYEcAlV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8GwLqCqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mOiWrE50, 2, m, &cDelay_mOiWrE50_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MRvyDH6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pQOGuKzg, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_l59eVvd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SwgYw1Am, HV_BINOP_SUBTRACT, 0, m, &cBinop_SwgYw1Am_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8Y3QB9JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kD3wOJx5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kD3wOJx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yPEwTWXm_sendMessage);
}

void Heavy_ChaffVerb::cVar_hHH8mEMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72LmSIOG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_WBYcI5GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WBYcI5GO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEotHceT, 0, m, &cDelay_nEotHceT_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XXtHz2aJ, 0, m, &sTabread_XXtHz2aJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_nEotHceT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nEotHceT, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XXtHz2aJ, 0, m, &sTabread_XXtHz2aJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEotHceT, 0, m, &cDelay_nEotHceT_sendMessage);
}

void Heavy_ChaffVerb::sTabread_XXtHz2aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oUqEXHhX, HV_BINOP_SUBTRACT, 0, m, &cBinop_oUqEXHhX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_tngAvvZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cLYrA2zp, HV_BINOP_MAX, 0, m, &cBinop_cLYrA2zp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yPEwTWXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tngAvvZI, HV_BINOP_MULTIPLY, 0, m, &cBinop_tngAvvZI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SwgYw1Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XT1FwWDf_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XXtHz2aJ, 0, m, &sTabread_XXtHz2aJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ksWFUmTl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nC82d24v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oUqEXHhX, HV_BINOP_SUBTRACT, 1, m, &cBinop_oUqEXHhX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEotHceT, 2, m, &cDelay_nEotHceT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_72LmSIOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nC82d24v_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XT1FwWDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBYcI5GO, 0, m, &cDelay_WBYcI5GO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEotHceT, 0, m, &cDelay_nEotHceT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OK5WTQkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_cLYrA2zp, HV_BINOP_MAX, 1, m, &cBinop_cLYrA2zp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cLYrA2zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SwgYw1Am, HV_BINOP_SUBTRACT, 1, m, &cBinop_SwgYw1Am_sendMessage);
}

void Heavy_ChaffVerb::cCast_ksWFUmTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBYcI5GO, 0, m, &cDelay_WBYcI5GO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_10LKd2FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBYcI5GO, 2, m, &cDelay_WBYcI5GO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oUqEXHhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_10LKd2FU_sendMessage);
}

void Heavy_ChaffVerb::cCast_zCBZ1YsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hHH8mEMQ, 0, m, &cVar_hHH8mEMQ_sendMessage);
  cMsg_8Y3QB9JX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_l59eVvd7, 0, m, &cTabhead_l59eVvd7_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_oA6FEcXo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jcTMzaqt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_jcTMzaqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtSI9g9Y_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_BVCti94y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfSV1rv8, HV_BINOP_ADD, 0, m, &cBinop_HfSV1rv8_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_1XXzireO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oHbWtBAP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_oHbWtBAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cHXomhM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_j2HEoNIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HAC5fZ19_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WeL1XDLf_sendMessage);
}

void Heavy_ChaffVerb::cVar_tbKx8pA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KoPqWL1n, 0, m, &cVar_KoPqWL1n_sendMessage);
}

void Heavy_ChaffVerb::cVar_KoPqWL1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dRWfjwQ0, HV_BINOP_ADD, 0, m, &cBinop_dRWfjwQ0_sendMessage);
}

void Heavy_ChaffVerb::cVar_4DQkKYwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ymHTXyPK, HV_BINOP_ADD, 0, m, &cBinop_ymHTXyPK_sendMessage);
}

void Heavy_ChaffVerb::cVar_r0lx1Kec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iaCECi2l_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qrv9niaV, 0, m, &cIf_qrv9niaV_sendMessage);
}

void Heavy_ChaffVerb::cUnop_58eu0Rt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ymHTXyPK, HV_BINOP_ADD, 1, m, &cBinop_ymHTXyPK_sendMessage);
}

void Heavy_ChaffVerb::cUnop_qJaCkDz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ymHTXyPK, HV_BINOP_ADD, 1, m, &cBinop_ymHTXyPK_sendMessage);
}

void Heavy_ChaffVerb::cIf_qrv9niaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_qJaCkDz4_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_58eu0Rt7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_iaCECi2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrv9niaV, 1, m, &cIf_qrv9niaV_sendMessage);
}

void Heavy_ChaffVerb::cVar_Di8H8Ty7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NVGbXpBa_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_a2oqWU0F, 0, m, &cIf_a2oqWU0F_sendMessage);
}

void Heavy_ChaffVerb::cUnop_eYh8fALV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AMA2fL8t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_v35VamBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AMA2fL8t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_a2oqWU0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_v35VamBy_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_eYh8fALV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_NVGbXpBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a2oqWU0F, 1, m, &cIf_a2oqWU0F_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_AMA2fL8t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iwTckHZX, 0, m, &cSlice_iwTckHZX_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IBlNnetp, 0, m, &cSlice_IBlNnetp_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WizEAHd7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FtwUpKJy_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_iwTckHZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_TJQq2K5k, 0, m, &cVar_TJQq2K5k_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TJQq2K5k, 0, m, &cVar_TJQq2K5k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_IBlNnetp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dMJkmgrs, HV_BINOP_NEQ, 1, m, &cBinop_dMJkmgrs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TJQq2K5k, 1, m, &cVar_TJQq2K5k_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dMJkmgrs, HV_BINOP_NEQ, 1, m, &cBinop_dMJkmgrs_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TJQq2K5k, 1, m, &cVar_TJQq2K5k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_TJQq2K5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QOFuJAZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U1qwUw5O_sendMessage);
}

void Heavy_ChaffVerb::cIf_D3RtrD0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z5EWNhWw_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zPixovGw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_Z5EWNhWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMJkmgrs, HV_BINOP_NEQ, 1, m, &cBinop_dMJkmgrs_sendMessage);
}

void Heavy_ChaffVerb::cCast_zPixovGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TJQq2K5k, 0, m, &cVar_TJQq2K5k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dMJkmgrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D3RtrD0a, 1, m, &cIf_D3RtrD0a_sendMessage);
}

void Heavy_ChaffVerb::cCast_FtwUpKJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D3RtrD0a, 0, m, &cIf_D3RtrD0a_sendMessage);
}

void Heavy_ChaffVerb::cCast_WizEAHd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMJkmgrs, HV_BINOP_NEQ, 0, m, &cBinop_dMJkmgrs_sendMessage);
}

void Heavy_ChaffVerb::cIf_0F47aLpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_rnAvuRed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0F47aLpB, 0, m, &cIf_0F47aLpB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_DtELNm5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0F47aLpB, 0, m, &cIf_0F47aLpB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_4973xQPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_0F47aLpB, 0, m, &cIf_0F47aLpB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_GUN4WcUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_j2HEoNIl, 0, m, &cVar_j2HEoNIl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_mJn4VgTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4DQkKYwK, 0, m, &cVar_4DQkKYwK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L3c3KXCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rnAvuRed, 1, m, &cIf_rnAvuRed_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xDIf1Jzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4973xQPn, 1, m, &cIf_4973xQPn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fxCzYGyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rnAvuRed, 1, m, &cIf_rnAvuRed_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_DtELNm5Z, 1, m, &cIf_DtELNm5Z_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4973xQPn, 1, m, &cIf_4973xQPn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dj984SFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BVCti94y, 0, m, &cVar_BVCti94y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SxbpIqlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dj984SFC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8cHXomhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_j2HEoNIl, 0, m, &cVar_j2HEoNIl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2pZWL2hY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CNZxVeAl, HV_BINOP_MULTIPLY, 0, m, &cBinop_CNZxVeAl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7oI9T88q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pZWL2hY, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_2pZWL2hY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Lh4WxEZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DtELNm5Z, 1, m, &cIf_DtELNm5Z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ymHTXyPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AyNSscE1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GtHxzk9d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ERibUBT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ecGbh7Pi, 0, m, &cVar_ecGbh7Pi_sendMessage);
}

void Heavy_ChaffVerb::cCast_AyNSscE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ERibUBT7, HV_BINOP_ADD, 1, m, &cBinop_ERibUBT7_sendMessage);
}

void Heavy_ChaffVerb::cCast_GtHxzk9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
}

void Heavy_ChaffVerb::cCast_U1qwUw5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UERDvgeh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_QOFuJAZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fxCzYGyN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_sBZybc12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iiayiZRw, 0, m, &cVar_iiayiZRw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CNZxVeAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DtELNm5Z, 0, m, &cIf_DtELNm5Z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2A8thIbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4973xQPn, 0, m, &cIf_4973xQPn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8dPAvibl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_w2PNROKd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_2A8thIbY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IywhcCvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_meImHsqF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_meImHsqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_8dPAvibl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BgR05A1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2HYqYUV3, 1, m, &cVar_2HYqYUV3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qL0ZZOBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gTpuD0JE, 0, m, &cVar_gTpuD0JE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OPeI5mh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yAnfxD7C, 0, m, &cVar_yAnfxD7C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wtSI9g9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HfSV1rv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJKuuL5u, HV_BINOP_MULTIPLY, 0, m, &cBinop_lJKuuL5u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lJKuuL5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GUN4WcUy, 0, m, &cIf_GUN4WcUy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MEzmc73m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ERibUBT7, HV_BINOP_ADD, 0, m, &cBinop_ERibUBT7_sendMessage);
}

void Heavy_ChaffVerb::cCast_HAC5fZ19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEzmc73m, HV_BINOP_ADD, 1, m, &cBinop_MEzmc73m_sendMessage);
}

void Heavy_ChaffVerb::cCast_WeL1XDLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
}

void Heavy_ChaffVerb::cCast_U5G0Epuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oA6FEcXo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Hv2Dnt08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0F47aLpB, 1, m, &cIf_0F47aLpB_sendMessage);
}

void Heavy_ChaffVerb::cCast_jArgfx3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJKuuL5u, HV_BINOP_MULTIPLY, 1, m, &cBinop_lJKuuL5u_sendMessage);
}

void Heavy_ChaffVerb::cCast_u4ZBsrIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BVCti94y, 0, m, &cVar_BVCti94y_sendMessage);
}

void Heavy_ChaffVerb::cCast_X4PDonJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1XXzireO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_d3z40l1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GUN4WcUy, 1, m, &cIf_GUN4WcUy_sendMessage);
}

void Heavy_ChaffVerb::cCast_fpB6eIky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfSV1rv8, HV_BINOP_ADD, 1, m, &cBinop_HfSV1rv8_sendMessage);
}

void Heavy_ChaffVerb::cCast_kw81lHop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BVCti94y, 0, m, &cVar_BVCti94y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XTffoJ45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MEzmc73m, HV_BINOP_ADD, 0, m, &cBinop_MEzmc73m_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dRWfjwQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTffoJ45, HV_BINOP_MULTIPLY, 0, m, &cBinop_XTffoJ45_sendMessage);
}

void Heavy_ChaffVerb::cCast_UgediTC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
}

void Heavy_ChaffVerb::cCast_2QI4eThF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTffoJ45, HV_BINOP_MULTIPLY, 1, m, &cBinop_XTffoJ45_sendMessage);
}

void Heavy_ChaffVerb::cCast_U1x8Eucj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dRWfjwQ0, HV_BINOP_ADD, 1, m, &cBinop_dRWfjwQ0_sendMessage);
}

void Heavy_ChaffVerb::cCast_uFJsRKZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tbKx8pA1, 0, m, &cVar_tbKx8pA1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ir3cJYZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QOFuJAZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U1qwUw5O_sendMessage);
}

void Heavy_ChaffVerb::cReceive_eSRPWwuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_orYXb1Bz_sendMessage(_c, 0, m);
  cMsg_usTKcGH8_sendMessage(_c, 0, m);
  cMsg_G0dYoS4n_sendMessage(_c, 0, m);
  cMsg_g2LO3srC_sendMessage(_c, 0, m);
  cMsg_B1z5Q4VV_sendMessage(_c, 0, m);
  cMsg_rUYKdLsP_sendMessage(_c, 0, m);
  cMsg_kcXx7fLp_sendMessage(_c, 0, m);
  cMsg_0zhCfikK_sendMessage(_c, 0, m);
  cMsg_yMqtiEPo_sendMessage(_c, 0, m);
  cMsg_FjdaW0Lk_sendMessage(_c, 0, m);
  cMsg_XWadHjB1_sendMessage(_c, 0, m);
  cMsg_qGparK4X_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IWTnBYd3, 0, m, &cVar_IWTnBYd3_sendMessage);
  cMsg_qduUvhHg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ha3HZMDR, 0, m, &cVar_ha3HZMDR_sendMessage);
  cMsg_wiSUTIWp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_py3ZK261, 0, m, &cVar_py3ZK261_sendMessage);
  cMsg_HjyzjNf6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p0V8mYsc, 0, m, &cVar_p0V8mYsc_sendMessage);
  cMsg_p5tx50YU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KomC7zOL, 0, m, &cVar_KomC7zOL_sendMessage);
  cMsg_KFoQ1NoB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gTpuD0JE, 0, m, &cVar_gTpuD0JE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3cgJmL8v, 0, m, &cVar_3cgJmL8v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iiayiZRw, 0, m, &cVar_iiayiZRw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b1OFOz1j, 0, m, &cVar_b1OFOz1j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HW7U9ZHZ, 0, m, &cVar_HW7U9ZHZ_sendMessage);
  cMsg_cIdDZ3mI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yAnfxD7C, 0, m, &cVar_yAnfxD7C_sendMessage);
  cMsg_SShF5cLc_sendMessage(_c, 0, m);
  cSwitchcase_IoHipF4B_onMessage(_c, NULL, 0, m, NULL);
  cMsg_wtSI9g9Y_sendMessage(_c, 0, m);
  cMsg_Ir3cJYZ8_sendMessage(_c, 0, m);
  cMsg_8cHXomhM_sendMessage(_c, 0, m);
  cSwitchcase_yS0Xohiz_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_1Pls3hDc, 0, m, &cVar_1Pls3hDc_sendMessage);
  cMsg_YJQH37gs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vW9nhsrM, 0, m, &cVar_vW9nhsrM_sendMessage);
  cMsg_2UoO3jlX_sendMessage(_c, 0, m);
  cMsg_CA5iR72e_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MWiNZmoj, 0, m, &cVar_MWiNZmoj_sendMessage);
  cMsg_HHwDKevx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nQeYA8Dc, 0, m, &cTabhead_nQeYA8Dc_sendMessage);
  cMsg_WbxrnGdy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bSLZvrQH, 0, m, &cVar_bSLZvrQH_sendMessage);
  cMsg_SfGZkofv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6YtNdUPX, 0, m, &cTabhead_6YtNdUPX_sendMessage);
  cMsg_NJhpiO0U_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VG98i2zS, 0, m, &cVar_VG98i2zS_sendMessage);
  cMsg_pE9bKwAz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_0ZlMKHuY, 0, m, &cTabhead_0ZlMKHuY_sendMessage);
  cMsg_5iOHH4as_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v7FY8Fh3, 0, m, &cVar_v7FY8Fh3_sendMessage);
  cMsg_1boz8Av8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jXiMF1Vt, 0, m, &cTabhead_jXiMF1Vt_sendMessage);
  cMsg_XOVp3GPo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PouJAbr4, 0, m, &cVar_PouJAbr4_sendMessage);
  cMsg_mCwKpdd7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OzI7Xhu9, 0, m, &cTabhead_OzI7Xhu9_sendMessage);
  cMsg_GpugSUnc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Pn9HIzjw, 0, m, &cVar_Pn9HIzjw_sendMessage);
  cMsg_vURJfGht_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3fIiqIPM, 0, m, &cTabhead_3fIiqIPM_sendMessage);
  cMsg_tEGHp8nh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_u17uO8S7, 0, m, &cVar_u17uO8S7_sendMessage);
  cMsg_kxIHDoQP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_pubX3OCm, 0, m, &cTabhead_pubX3OCm_sendMessage);
  cMsg_osYIFwwE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kbwKxudN, 0, m, &cVar_kbwKxudN_sendMessage);
  cMsg_IomwOMaU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IPF5ofO5, 0, m, &cTabhead_IPF5ofO5_sendMessage);
  cMsg_hy38LkkD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tYwdfKC4, 0, m, &cVar_tYwdfKC4_sendMessage);
  cMsg_cWLvY9Ec_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uCDU8DiK, 0, m, &cTabhead_uCDU8DiK_sendMessage);
  cMsg_zAhpqgny_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BHbgXlxj, 0, m, &cVar_BHbgXlxj_sendMessage);
  cMsg_xZYbFLKD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5OCkNgOM, 0, m, &cTabhead_5OCkNgOM_sendMessage);
  cMsg_OK5WTQkr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hHH8mEMQ, 0, m, &cVar_hHH8mEMQ_sendMessage);
  cMsg_8Y3QB9JX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_l59eVvd7, 0, m, &cTabhead_l59eVvd7_sendMessage);
}

void Heavy_ChaffVerb::cReceive_emJwa5yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_qL0ZZOBu_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ANXHegV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Di8H8Ty7, 0, m, &cVar_Di8H8Ty7_sendMessage);
}

void Heavy_ChaffVerb::cReceive_HNLJRgiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Jc5ghAm, 0, m, &cVar_8Jc5ghAm_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QVkt4wEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CNZxVeAl, HV_BINOP_MULTIPLY, 1, m, &cBinop_CNZxVeAl_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZXpglU67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U1x8Eucj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uFJsRKZw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Ei0OBn51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2QI4eThF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UgediTC2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pIWxbU7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4DQkKYwK, 0, m, &cVar_4DQkKYwK_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aE1Sk30e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mJn4VgTT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r0lx1Kec, 0, m, &cVar_r0lx1Kec_sendMessage);
}

void Heavy_ChaffVerb::cReceive_DZbXOBVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_OPeI5mh2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_SXlY6XOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpB6eIky_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kw81lHop_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7wnATPM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jArgfx3i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u4ZBsrIl_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7yKVXtb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d3z40l1s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X4PDonJw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_FtBOPv9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7yFkJW6y, m);
}

void Heavy_ChaffVerb::cReceive_0ITo3QOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TQKWY23o, m);
}

void Heavy_ChaffVerb::cReceive_pz0No5CA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3cgJmL8v, 0, m, &cVar_3cgJmL8v_sendMessage);
}

void Heavy_ChaffVerb::cReceive_67PYWRIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_sBZybc12_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JTWmXBUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6udZ4HDi, 0, m, &cVar_6udZ4HDi_sendMessage);
}

void Heavy_ChaffVerb::cReceive_lOYjLDod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2avIbLMp, 0, m, &cVar_2avIbLMp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_j6rBFqld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KomC7zOL, 0, m, &cVar_KomC7zOL_sendMessage);
}

void Heavy_ChaffVerb::cReceive_OKGH1aHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ev7W7Fie, m);
}

void Heavy_ChaffVerb::cReceive_Kn6MXJ8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hau0OBsI, m);
}

void Heavy_ChaffVerb::cReceive_ArJ44XwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tngAvvZI, HV_BINOP_MULTIPLY, 1, m, &cBinop_tngAvvZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zCBZ1YsA_sendMessage);
}

void Heavy_ChaffVerb::cReceive_eT2cHFC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hv2Dnt08_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U5G0Epuo_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_0VjlSm5H, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_oqGF3J4a, VOf(Bf4));
    __hv_line_f(&sLine_s9rLL2Zw, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_tfA052OY, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_0WZR9ohu, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_go125gOo, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_uXOp2dFT, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_CGAJlvDG, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_EYbzL6TP, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_uvN1tyDm, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Bdp4hO8E, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_6wjKPV7N, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_Zwp2llak, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_0g303sTK, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_8IvGfGMS, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_4fx4BH2w, VIf(I0));
    __hv_varread_f(&sVarf_QkBR6cn3, VOf(Bf2));
    __hv_rpole_f(&sRPole_pxnBlMo1, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_bBi8lbUv, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_APXmZaAy, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ev7W7Fie, VOf(Bf1));
    __hv_tabread_f(&sTabread_XXtHz2aJ, VOf(Bf5));
    __hv_varread_f(&sVarf_hau0OBsI, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_pQOGuKzg, VIf(Bf9));
    __hv_varread_f(&sVarf_TQKWY23o, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_BoWRiEAT, VOf(Bf9));
    __hv_varread_f(&sVarf_5vDhtPJB, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_oO75cqZB, VOf(Bf2));
    __hv_rpole_f(&sRPole_c0ZISSra, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_NA1DmgYx, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_dTjgUxY3, VOf(Bf2));
    __hv_tabread_f(&sTabread_UMrkrym0, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_H5SZR1fn, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_x30HpyjE, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_mXX5ho42, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_dMJfdbuF, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_Tr02v7aG, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_K0uXIN5h, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_GVaU32Uj, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_DyikTmQA, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_XgEPBFuq, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_XjNCXCCx, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_VtQhKxcn, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_IYp1yUn7, VOf(Bf9));
    __hv_varread_f(&sVarf_Pf9CTUyK, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_x6e8wN31, VOf(Bf3));
    __hv_rpole_f(&sRPole_gqX9U0Gp, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_BKw3EDjM, VOf(Bf3));
    __hv_varread_f(&sVarf_Sc8QRQ1L, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_GZjrIoYq, VOf(Bf12));
    __hv_rpole_f(&sRPole_1Mw648mB, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_5QalpX1l, VOf(Bf12));
    __hv_varread_f(&sVarf_lVw1x0QF, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_9x8oP7Qq, VOf(Bf11));
    __hv_rpole_f(&sRPole_nyUJhD1X, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_WwHAjcJL, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_PC3Un7ur, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_pAP82yt1, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_Y6JA3G1e, VIf(Bf11));
    __hv_line_f(&sLine_1eMOLNSD, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_7yFkJW6y, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
